@@ -92,14 +92,10 @@ build_deps(){
                         INSTALLED+=("openjdk-8-jdk")
                         INSTALLED+=("openjdk-8-source")
                         INSTALLED+=("maven")
-                    elif [ "$FOUND_VALUE" = "lua" ]; then
-                        INSTALLED+=("liblua5.1-0-dev")
                     elif [ "$FOUND_VALUE" = "gpsd" ]; then
                         INSTALLED+=("libgps-dev")
                     elif [ "$FOUND_VALUE" = "libarchive" ]; then
                         INSTALLED+=("liblzma-dev")
-                    elif [ "$FOUND_VALUE" = "boost" ]; then
-                        INSTALLED+=("libboost-dev")
                     elif [ "$FOUND_VALUE" = "opensslbuild" ]; then
                         INSTALLED+=("perl")
                     fi
