@@ -70,14 +70,10 @@ build_deps(){
                     elif [ "$FOUND_VALUE" = "jnibuild" ]; then
                         INSTALLED+=("jdk8-openjdk")
                         INSTALLED+=("maven")
-                    elif [ "$FOUND_VALUE" = "lua" ]; then
-                        INSTALLED+=("lua")
                     elif [ "$FOUND_VALUE" = "gpsd" ]; then
                         INSTALLED+=("gpsd")
                     elif [ "$FOUND_VALUE" = "libarchive" ]; then
                         INSTALLED+=("libarchive")
-                    elif [ "$FOUND_VALUE" = "boost" ]; then
-                        INSTALLED+=("boost")
                     elif [ "$FOUND_VALUE" = "opensslbuild" ]; then
                         INSTALLED+=("perl")
                     fi
