@@ -258,20 +258,20 @@ add_cmake_option PORTABLE_BUILD ${TRUE}
 add_cmake_option DEBUG_SYMBOLS ${FALSE}
 add_cmake_option BUILD_ROCKSDB ${TRUE}
 ## uses the source from the third party directory
-add_option ROCKSDB_ENABLED ${TRUE} "DISABLE_ROCKSDB"
+add_option ROCKSDB_ENABLED ${TRUE} "ENABLE_ROCKSDB"
 ## need libcurl installed
-add_option HTTP_CURL_ENABLED ${TRUE} "DISABLE_CURL"
+add_option HTTP_CURL_ENABLED ${TRUE} "ENABLE_CURL"
 
 # third party directory
-add_option LIBARCHIVE_ENABLED ${TRUE} "DISABLE_LIBARCHIVE"
+add_option LIBARCHIVE_ENABLED ${TRUE} "ENABLE_LIBARCHIVE"
 add_dependency LIBARCHIVE_ENABLED "libarchive"
 
-add_option PYTHON_SCRIPTING_ENABLED ${FALSE} "ENABLE_PYTHON_SCRIPTING"
+add_option PYTHON_SCRIPTING_ENABLED ${TRUE} "ENABLE_PYTHON_SCRIPTING"
 add_dependency PYTHON_SCRIPTING_ENABLED "python"
-add_option LUA_SCRIPTING_ENABLED ${FALSE} "ENABLE_LUA_SCRIPTING"
+add_option LUA_SCRIPTING_ENABLED ${TRUE} "ENABLE_LUA_SCRIPTING"
 add_dependency LUA_SCRIPTING_ENABLED "lua"
 
-add_option EXPRESSION_LANGUAGE_ENABLED ${TRUE} "DISABLE_EXPRESSION_LANGUAGE"
+add_option EXPRESSION_LANGUAGE_ENABLED ${TRUE} "ENABLE_EXPRESSION_LANGUAGE"
 add_dependency EXPRESSION_LANGUAGE_ENABLED "bison"
 add_dependency EXPRESSION_LANGUAGE_ENABLED "flex"
 
@@ -289,9 +289,9 @@ add_option AWS_ENABLED ${TRUE} "ENABLE_AWS"
 
 add_option KAFKA_ENABLED ${TRUE} "ENABLE_LIBRDKAFKA"
 
-add_option KUBERNETES_ENABLED ${FALSE} "ENABLE_KUBERNETES"
+add_option KUBERNETES_ENABLED ${TRUE} "ENABLE_KUBERNETES"
 
-add_option MQTT_ENABLED ${FALSE} "ENABLE_MQTT"
+add_option MQTT_ENABLED ${TRUE} "ENABLE_MQTT"
 
 add_option COAP_ENABLED ${FALSE} "ENABLE_COAP"
 add_dependency COAP_ENABLED "automake"
@@ -303,8 +303,6 @@ add_dependency JNI_ENABLED "jnibuild"
 
 add_option OPENCV_ENABLED ${FALSE} "ENABLE_OPENCV"
 
-add_option OPENCV_ENABLED ${FALSE} "ENABLE_OPENCV"
-
 add_option SFTP_ENABLED ${FALSE} "ENABLE_SFTP"
 add_dependency SFTP_ENABLED "libssh2"
 
@@ -314,9 +312,8 @@ add_option OPENWSMAN_ENABLED ${FALSE} "ENABLE_OPENWSMAN"
 
 # Since the following extensions have limitations on
 add_option BUSTACHE_ENABLED ${FALSE} "ENABLE_BUSTACHE" "2.6" ${TRUE}
-add_dependency BUSTACHE_ENABLED "boost"
 
-add_option OPC_ENABLED ${FALSE} "ENABLE_OPC"
+add_option OPC_ENABLED ${TRUE} "ENABLE_OPC"
 add_dependency OPC_ENABLED "mbedtls"
 
 add_option AZURE_ENABLED ${TRUE} "ENABLE_AZURE"
@@ -332,19 +329,22 @@ set_dependency SPLUNK_ENABLED HTTP_CURL_ENABLED
 
 add_option GCP_ENABLED ${TRUE} "ENABLE_GCP"
 
-add_option ELASTIC_ENABLED ${FALSE} "ENABLE_ELASTICSEARCH"
+add_option ELASTIC_ENABLED ${TRUE} "ENABLE_ELASTICSEARCH"
 set_dependency ELASTIC_ENABLED HTTP_CURL_ENABLED
 
+add_option GRAFANA_LOKI_ENABLED ${FALSE} "ENABLE_GRAFANA_LOKI"
+set_dependency GRAFANA_LOKI_ENABLED HTTP_CURL_ENABLED
+
 add_option PROCFS_ENABLED ${TRUE} "ENABLE_PROCFS"
 
-add_option PROMETHEUS_ENABLED ${FALSE} "ENABLE_PROMETHEUS"
+add_option PROMETHEUS_ENABLED ${TRUE} "ENABLE_PROMETHEUS"
 
-add_option OPENSSL_ENABLED ${TRUE} "OPENSSL_OFF"
+add_option OPENSSL_ENABLED ${TRUE} "MINIFI_OPENSSL"
 add_dependency OPENSSL_ENABLED "opensslbuild"
 
 USE_SHARED_LIBS=${TRUE}
 ASAN_ENABLED=${FALSE}
-FAIL_ON_WARNINGS=${FALSE}
+MINIFI_FAIL_ON_WARNINGS=${FALSE}
 TESTS_ENABLED=${TRUE}
 
 ## name, default, values
@@ -444,8 +444,9 @@ build_cmake_command(){
     if [ "$FOUND" = "1" ]; then
       set_value=OFF
       option_value="${!option}"
-      if { [[ "$option_value" = "${FALSE}" ]] && { [[ "$FOUND_VALUE" == "DISABLE"* ]] || [[ "$FOUND_VALUE" == *"OFF" ]]; }; } || \
-         { [[ "$option_value" = "${TRUE}" ]] && [[ "$FOUND_VALUE" == "ENABLE"* ]]; }; then
+      if { [[ "$option_value" = "${FALSE}" ]] && [[ "$FOUND_VALUE" == "DISABLE"* ]]; } || \
+         { [[ "$option_value" = "${TRUE}" ]] && [[ "$FOUND_VALUE" == "ENABLE"* ]]; } || \
+         { [[ "$option_value" = "${TRUE}" ]] && [[ "$FOUND_VALUE" != "ENABLE"* ]] && [[ "$FOUND_VALUE" != "DISABLE"* ]]; }; then
         set_value=ON
       fi
       CMAKE_BUILD_COMMAND="${CMAKE_BUILD_COMMAND} -D${FOUND_VALUE}=${set_value}"
@@ -464,9 +465,9 @@ build_cmake_command(){
   fi
 
   if [ "${ASAN_ENABLED}" = "${TRUE}" ]; then
-    CMAKE_BUILD_COMMAND="${CMAKE_BUILD_COMMAND} -DASAN_BUILD=ON "
+    CMAKE_BUILD_COMMAND="${CMAKE_BUILD_COMMAND} -DMINIFI_ADVANCED_ASAN_BUILD=ON "
   else
-    CMAKE_BUILD_COMMAND="${CMAKE_BUILD_COMMAND} -DASAN_BUILD=OFF"
+    CMAKE_BUILD_COMMAND="${CMAKE_BUILD_COMMAND} -DMINIFI_ADVANCED_ASAN_BUILD=OFF"
   fi
 
   if [ "${USE_SHARED_LIBS}" = "${TRUE}" ]; then
@@ -489,10 +490,10 @@ build_cmake_command(){
     CMAKE_BUILD_COMMAND="${CMAKE_BUILD_COMMAND} -DBUILD_ROCKSDB= "
   fi
 
-  if [ "${FAIL_ON_WARNINGS}" = "${TRUE}" ]; then
-    CMAKE_BUILD_COMMAND="${CMAKE_BUILD_COMMAND} -DFAIL_ON_WARNINGS=ON "
+  if [ "${MINIFI_FAIL_ON_WARNINGS}" = "${TRUE}" ]; then
+    CMAKE_BUILD_COMMAND="${CMAKE_BUILD_COMMAND} -DMINIFI_FAIL_ON_WARNINGS=ON "
   else
-    CMAKE_BUILD_COMMAND="${CMAKE_BUILD_COMMAND} -DFAIL_ON_WARNINGS=OFF"
+    CMAKE_BUILD_COMMAND="${CMAKE_BUILD_COMMAND} -DMINIFI_FAIL_ON_WARNINGS=OFF"
   fi
 
   CMAKE_BUILD_COMMAND="${CMAKE_BUILD_COMMAND} -DBUILD_IDENTIFIER=${BUILD_IDENTIFIER}"
