@@ -164,7 +164,7 @@ save_state(){
   echo_state_variable BUILD_PROFILE
   echo_state_variable USE_SHARED_LIBS
   echo_state_variable ASAN_ENABLED
-  echo_state_variable FAIL_ON_WARNINGS
+  echo_state_variable MINIFI_FAIL_ON_WARNINGS
   for option in "${OPTIONS[@]}" ; do
     echo_state_variable "${option}"
   done
@@ -389,6 +389,7 @@ show_supported_features() {
   echo "AD. ProcFs Support .............$(print_feature_status PROCFS_ENABLED)"
   echo "AE. Prometheus Support .........$(print_feature_status PROMETHEUS_ENABLED)"
   echo "AF. Elasticsearch Support ......$(print_feature_status ELASTIC_ENABLED)"
+  echo "AG. Grafana Loki Support .......$(print_feature_status GRAFANA_LOKI_ENABLED)"
   echo "****************************************"
   echo "            Build Options."
   echo "****************************************"
@@ -398,7 +399,7 @@ show_supported_features() {
   echo "4. Use Shared Dependency Links .$(print_feature_status USE_SHARED_LIBS)"
   echo "5. Build Profile ...............$(print_multi_option_status BUILD_PROFILE)"
   echo "6. Create ASAN build ...........$(print_feature_status ASAN_ENABLED)"
-  echo "7. Treat warnings as errors.....$(print_feature_status FAIL_ON_WARNINGS)"
+  echo "7. Treat warnings as errors.....$(print_feature_status MINIFI_FAIL_ON_WARNINGS)"
   echo "8. Enable OpenSSL...............$(print_feature_status OPENSSL_ENABLED)"
   echo "P. Continue with these options"
   if [ "$GUIDED_INSTALL" = "${TRUE}" ]; then
@@ -444,13 +445,14 @@ read_feature_options(){
     ad) ToggleFeature PROCFS_ENABLED ;;
     ae) ToggleFeature PROMETHEUS_ENABLED ;;
     af) ToggleFeature ELASTIC_ENABLED ;;
+    ag) ToggleFeature GRAFANA_LOKI_ENABLED ;;
     1) ToggleFeature TESTS_ENABLED ;;
     2) EnableAllFeatures ;;
     3) ToggleFeature JNI_ENABLED;;
     4) ToggleFeature USE_SHARED_LIBS;;
     5) ToggleMultiOption BUILD_PROFILE;;
     6) ToggleFeature ASAN_ENABLED;;
-    7) ToggleFeature FAIL_ON_WARNINGS;;
+    7) ToggleFeature MINIFI_FAIL_ON_WARNINGS;;
     8) ToggleFeature OPENSSL_ENABLED;;
     p) export FEATURES_SELECTED="true" ;;
     r) if [ "$GUIDED_INSTALL" = "${TRUE}" ]; then
