@@ -73,8 +73,6 @@ build_deps(){
             INSTALLED+=("libtool")
           elif [ "$FOUND_VALUE" = "python" ]; then
             INSTALLED+=("libpython3-dev")
-          elif [ "$FOUND_VALUE" = "lua" ]; then
-            INSTALLED+=("liblua5.1-0-dev")
           elif [ "$FOUND_VALUE" = "jnibuild" ]; then
             INSTALLED+=("openjdk-11-jdk")
             INSTALLED+=("openjdk-11-source")
@@ -87,8 +85,6 @@ build_deps(){
             INSTALLED+=("liblzma-dev")
           elif [ "$FOUND_VALUE" = "libssh2" ]; then
             INSTALLED+=("libssh2-1-dev")
-          elif [ "$FOUND_VALUE" = "boost" ]; then
-            INSTALLED+=("libboost-dev")
           elif [ "$FOUND_VALUE" = "opensslbuild" ]; then
             INSTALLED+=("perl")
           fi
