@@ -35,6 +35,9 @@ from .containers.MinifiAsPodInKubernetesCluster import MinifiAsPodInKubernetesCl
 from .containers.TcpClientContainer import TcpClientContainer
 from .containers.PrometheusContainer import PrometheusContainer
 from .containers.MinifiC2ServerContainer import MinifiC2ServerContainer
+from .containers.GrafanaLokiContainer import GrafanaLokiContainer
+from .containers.GrafanaLokiContainer import GrafanaLokiOptions
+from .containers.ReverseProxyContainer import ReverseProxyContainer
 from .FeatureContext import FeatureContext
 
 
@@ -42,6 +45,7 @@ class ContainerStore:
     def __init__(self, network, image_store, kubernetes_proxy, feature_id):
         self.feature_id = feature_id
         self.minifi_options = MinifiOptions()
+        self.grafana_loki_options = GrafanaLokiOptions()
         self.containers = {}
         self.data_directories = {}
         self.network = network
@@ -269,6 +273,23 @@ class ContainerStore:
                                                                       image_store=self.image_store,
                                                                       command=command,
                                                                       ssl=True))
+        elif engine == "grafana-loki-server":
+            return self.containers.setdefault(container_name,
+                                              GrafanaLokiContainer(feature_context=feature_context,
+                                                                   name=container_name,
+                                                                   vols=self.vols,
+                                                                   network=self.network,
+                                                                   image_store=self.image_store,
+                                                                   options=self.grafana_loki_options,
+                                                                   command=command))
+        elif engine == "reverse-proxy":
+            return self.containers.setdefault(container_name,
+                                              ReverseProxyContainer(feature_context=feature_context,
+                                                                    name=container_name,
+                                                                    vols=self.vols,
+                                                                    network=self.network,
+                                                                    image_store=self.image_store,
+                                                                    command=command))
         else:
             raise Exception('invalid flow engine: \'%s\'' % engine)
 
@@ -328,6 +349,18 @@ class ContainerStore:
     def enable_sql_in_minifi(self):
         self.minifi_options.enable_sql = True
 
+    def use_nifi_python_processors_with_system_python_packages_installed_in_minifi(self):
+        self.minifi_options.use_nifi_python_processors_with_system_python_packages_installed = True
+
+    def use_nifi_python_processors_with_virtualenv_in_minifi(self):
+        self.minifi_options.use_nifi_python_processors_with_virtualenv = True
+
+    def use_nifi_python_processors_with_virtualenv_packages_installed_in_minifi(self):
+        self.minifi_options.use_nifi_python_processors_with_virtualenv_packages_installed = True
+
+    def remove_python_requirements_txt_in_minifi(self):
+        self.minifi_options.remove_python_requirements_txt = True
+
     def set_yaml_in_minifi(self):
         self.minifi_options.config_format = "yaml"
 
@@ -337,6 +370,9 @@ class ContainerStore:
     def enable_log_metrics_publisher_in_minifi(self):
         self.minifi_options.enable_log_metrics_publisher = True
 
+    def enable_example_minifi_python_processors(self):
+        self.minifi_options.enable_example_minifi_python_processors = True
+
     def get_startup_finished_log_entry(self, container_name):
         container_name = self.get_container_name_with_postfix(container_name)
         return self.containers[container_name].get_startup_finished_log_entry()
@@ -351,3 +387,9 @@ class ContainerStore:
 
     def get_container_names(self, engine=None):
         return [key for key in self.containers.keys() if not engine or self.containers[key].get_engine() == engine]
+
+    def enable_ssl_in_grafana_loki(self):
+        self.grafana_loki_options.enable_ssl = True
+
+    def enable_multi_tenancy_in_grafana_loki(self):
+        self.grafana_loki_options.enable_multi_tenancy = True
