@@ -15,6 +15,12 @@
 import logging
 import time
 import re
+import tarfile
+import tempfile
+import os
+import gzip
+import shutil
+from typing import List
 
 from .LogSource import LogSource
 from .ContainerStore import ContainerStore
@@ -27,6 +33,7 @@ from .checkers.GcsChecker import GcsChecker
 from .checkers.PostgresChecker import PostgresChecker
 from .checkers.PrometheusChecker import PrometheusChecker
 from .checkers.SplunkChecker import SplunkChecker
+from .checkers.GrafanaLokiChecker import GrafanaLokiChecker
 from utils import get_peak_memory_usage, get_minifi_pid, get_memory_usage, retry_check
 
 
@@ -43,6 +50,7 @@ class DockerTestCluster:
         self.postgres_checker = PostgresChecker(self.container_communicator)
         self.splunk_checker = SplunkChecker(self.container_communicator)
         self.prometheus_checker = PrometheusChecker()
+        self.grafana_loki_checker = GrafanaLokiChecker()
         self.minifi_controller_executor = MinifiControllerExecutor(self.container_communicator)
 
     def cleanup(self):
@@ -93,6 +101,24 @@ class DockerTestCluster:
     def enable_sql_in_minifi(self):
         self.container_store.enable_sql_in_minifi()
 
+    def enable_ssl_in_grafana_loki(self):
+        self.container_store.enable_ssl_in_grafana_loki()
+
+    def enable_multi_tenancy_in_grafana_loki(self):
+        self.container_store.enable_multi_tenancy_in_grafana_loki()
+
+    def use_nifi_python_processors_with_system_python_packages_installed_in_minifi(self):
+        self.container_store.use_nifi_python_processors_with_system_python_packages_installed_in_minifi()
+
+    def use_nifi_python_processors_with_virtualenv_in_minifi(self):
+        self.container_store.use_nifi_python_processors_with_virtualenv_in_minifi()
+
+    def use_nifi_python_processors_with_virtualenv_packages_installed_in_minifi(self):
+        self.container_store.use_nifi_python_processors_with_virtualenv_packages_installed_in_minifi()
+
+    def remove_python_requirements_txt_in_minifi(self):
+        self.container_store.remove_python_requirements_txt_in_minifi()
+
     def set_yaml_in_minifi(self):
         self.container_store.set_yaml_in_minifi()
 
@@ -102,6 +128,9 @@ class DockerTestCluster:
     def enable_log_metrics_publisher_in_minifi(self):
         self.container_store.enable_log_metrics_publisher_in_minifi()
 
+    def enable_example_minifi_python_processors(self):
+        self.container_store.enable_example_minifi_python_processors()
+
     def get_app_log(self, container_name):
         container_name = self.container_store.get_container_name_with_postfix(container_name)
         log_source = self.container_store.log_source(container_name)
@@ -199,6 +228,10 @@ class DockerTestCluster:
         container_name = self.container_store.get_container_name_with_postfix(container_name)
         return self.splunk_checker.enable_splunk_hec_ssl(container_name, splunk_cert_pem, splunk_key_pem, root_ca_cert_pem)
 
+    def get_splunk_token(self, container_name, hec_name):
+        container_name = self.container_store.get_container_name_with_postfix(container_name)
+        return self.splunk_checker.get_splunk_token(container_name, hec_name)
+
     def check_google_cloud_storage(self, gcs_container_name, content):
         gcs_container_name = self.container_store.get_container_name_with_postfix(gcs_container_name)
         return self.gcs_checker.check_google_cloud_storage(gcs_container_name, content)
@@ -340,7 +373,44 @@ class DockerTestCluster:
     def check_connection_size_through_controller(self, connection: str, size: int, max_size: int, container_name: str) -> bool:
         return self.minifi_controller_executor.get_connection_size(connection, container_name) == (size, max_size)
 
-    @retry_check(10, 1000)
+    @retry_check(10, 1)
     def manifest_can_be_retrieved_through_minifi_controller(self, container_name: str) -> bool:
         manifest = self.minifi_controller_executor.get_manifest(container_name)
         return '"agentManifest": {' in manifest and '"componentManifest": {' in manifest and '"agentType": "cpp"' in manifest
+
+    @retry_check(10, 1)
+    def debug_bundle_can_be_retrieved_through_minifi_controller(self, container_name: str) -> bool:
+        with tempfile.TemporaryDirectory() as td:
+            result = self.minifi_controller_executor.get_debug_bundle(container_name, td)
+            if not result:
+                logging.error("Failed to get debug bundle")
+                return False
+
+            with tarfile.open(os.path.join(td, "debug.tar.gz")) as file:
+                file.extractall(td)
+
+            if not os.path.exists(os.path.join(td, "config.yml")):
+                logging.error("config.yml file was not found in debug bundle")
+                return False
+
+            if not os.path.exists(os.path.join(td, "minifi.properties")):
+                logging.error("minifi.properties file was not found in debug bundle")
+                return False
+
+            if not os.path.exists(os.path.join(td, "minifi.log.gz")):
+                logging.error("minifi.log.gz file was not found in debug bundle")
+                return False
+
+            with gzip.open(os.path.join(td, "minifi.log.gz"), 'rb') as f_in:
+                with open(os.path.join(td, "minifi.log"), 'wb') as f_out:
+                    shutil.copyfileobj(f_in, f_out)
+
+            with open(os.path.join(td, "minifi.log")) as f:
+                if 'MiNiFi started' not in f.read():
+                    logging.error("'MiNiFi started' log entry was not found in minifi.log file")
+                    return False
+
+            return True
+
+    def wait_for_lines_on_grafana_loki(self, lines: List[str], timeout_seconds: int, ssl: bool, tenant_id: str):
+        return self.grafana_loki_checker.wait_for_lines_on_grafana_loki(lines, timeout_seconds, ssl, tenant_id)
