@@ -33,11 +33,16 @@ class MinifiOptions:
         self.enable_prometheus = False
         self.enable_prometheus_with_ssl = False
         self.enable_sql = False
+        self.use_nifi_python_processors_with_system_python_packages_installed = False
+        self.use_nifi_python_processors_with_virtualenv = False
+        self.use_nifi_python_processors_with_virtualenv_packages_installed = False
+        self.remove_python_requirements_txt = False
         self.config_format = "json"
         self.use_flow_config_from_url = False
         self.set_ssl_context_properties = False
         self.enable_controller_socket = False
         self.enable_log_metrics_publisher = False
+        self.enable_example_minifi_python_processors = False
 
 
 class MinifiContainer(FlowContainer):
@@ -147,6 +152,14 @@ class MinifiContainer(FlowContainer):
                 f.write("controller.socket.port=9998\n")
                 f.write("controller.socket.local.any.interface=false\n")
 
+            if self.options.use_nifi_python_processors_with_virtualenv or self.options.remove_python_requirements_txt:
+                f.write("nifi.python.virtualenv.directory=/opt/minifi/minifi-current/venv\n")
+            elif self.options.use_nifi_python_processors_with_virtualenv_packages_installed:
+                f.write("nifi.python.virtualenv.directory=/opt/minifi/minifi-current/venv-with-langchain\n")
+
+            if self.options.use_nifi_python_processors_with_virtualenv or self.options.remove_python_requirements_txt:
+                f.write("nifi.python.install.packages.automatically=true\n")
+
     def _setup_config(self):
         self._create_properties()
         if not self.options.use_flow_config_from_url:
@@ -165,6 +178,14 @@ class MinifiContainer(FlowContainer):
 
         if self.options.enable_sql:
             image = self.image_store.get_image('minifi-cpp-sql')
+        elif self.options.enable_example_minifi_python_processors:
+            image = self.image_store.get_image('minifi-cpp-with-example-python-processors')
+        elif self.options.use_nifi_python_processors_with_system_python_packages_installed:
+            image = self.image_store.get_image('minifi-cpp-nifi-python-system-python-packages')
+        elif self.options.use_nifi_python_processors_with_virtualenv or self.options.use_nifi_python_processors_with_virtualenv_packages_installed:
+            image = self.image_store.get_image('minifi-cpp-nifi-python')
+        elif self.options.remove_python_requirements_txt:
+            image = self.image_store.get_image('minifi-cpp-nifi-with-inline-python-dependencies')
         else:
             image = 'apacheminificpp:' + MinifiContainer.MINIFI_TAG_PREFIX + MinifiContainer.MINIFI_VERSION
 
