@@ -17,6 +17,7 @@
 import logging
 import time
 import uuid
+from typing import List
 
 import OpenSSL.crypto
 
@@ -27,6 +28,7 @@ from minifi.core.InputPort import InputPort
 
 from cluster.DockerTestCluster import DockerTestCluster
 
+from minifi.validators.OutputValidator import OutputValidator
 from minifi.validators.EmptyFilesOutPutValidator import EmptyFilesOutPutValidator
 from minifi.validators.NoFileOutPutValidator import NoFileOutPutValidator
 from minifi.validators.SingleFileOutputValidator import SingleFileOutputValidator
@@ -35,6 +37,7 @@ from minifi.validators.SingleOrMultiFileOutputValidator import SingleOrMultiFile
 from minifi.validators.SingleOrMultiFileOutputRegexValidator import SingleOrMultiFileOutputRegexValidator
 from minifi.validators.NoContentCheckFileNumberValidator import NoContentCheckFileNumberValidator
 from minifi.validators.NumFileRangeValidator import NumFileRangeValidator
+from minifi.validators.NumFileRangeAndFileSizeValidator import NumFileRangeAndFileSizeValidator
 from minifi.validators.SingleJSONFileOutputValidator import SingleJSONFileOutputValidator
 from utils import decode_escaped_str, get_minifi_pid, get_peak_memory_usage
 
@@ -113,6 +116,12 @@ class MiNiFi_integration_test:
         assert self.cluster.wait_for_container_startup_to_finish('splunk')
         assert self.cluster.enable_splunk_hec_indexer('splunk', 'splunk_hec_token')
 
+    def get_splunk_token(self):
+        token = self.cluster.get_splunk_token('splunk', 'splunk_hec_token')
+        if token is None:
+            raise Exception("Failed to get Splunk token")
+        return token
+
     def start_elasticsearch(self, context):
         self.cluster.acquire_container(context=context, name='elasticsearch', engine='elasticsearch')
         self.cluster.deploy_container('elasticsearch')
@@ -180,7 +189,7 @@ class MiNiFi_integration_test:
         for node in self.remote_process_groups:
             if name == node.get_name():
                 return node
-        raise Exception("Trying to fetch unknow node: \"%s\"" % name)
+        raise Exception("Trying to fetch unknown node: \"%s\"" % name)
 
     @staticmethod
     def generate_input_port_for_remote_process_group(remote_process_group, name):
@@ -244,11 +253,21 @@ class MiNiFi_integration_test:
         output_validator.set_output_dir(self.file_system_observer.get_output_dir())
         self.__check_output(timeout_seconds, output_validator, max(1, num_flowfiles))
 
-    def check_for_num_file_range_generated(self, min_files, max_files, wait_time_in_seconds):
+    def check_for_num_file_range_generated_after_wait(self, min_files: int, max_files: int, wait_time_in_seconds: int):
         output_validator = NumFileRangeValidator(min_files, max_files)
         output_validator.set_output_dir(self.file_system_observer.get_output_dir())
         self.__check_output_after_time_period(wait_time_in_seconds, output_validator)
 
+    def check_for_num_file_range_generated_with_timeout(self, min_files: int, max_files: int, timeout_in_seconds: int):
+        output_validator = NumFileRangeValidator(min_files, max_files)
+        output_validator.set_output_dir(self.file_system_observer.get_output_dir())
+        self.__check_output_over_time_period(timeout_in_seconds, output_validator)
+
+    def check_for_num_file_range_and_min_size_generated(self, min_files: int, max_files: int, min_size: int, wait_time_in_seconds: int):
+        output_validator = NumFileRangeAndFileSizeValidator(min_files, max_files, min_size)
+        output_validator.set_output_dir(self.file_system_observer.get_output_dir())
+        self.__check_output_over_time_period(wait_time_in_seconds, output_validator)
+
     def check_for_an_empty_file_generated(self, timeout_seconds):
         output_validator = EmptyFilesOutPutValidator()
         output_validator.set_output_dir(self.file_system_observer.get_output_dir())
@@ -258,6 +277,17 @@ class MiNiFi_integration_test:
         time.sleep(wait_time_in_seconds)
         self.__validate(output_validator)
 
+    def __check_output_over_time_period(self, wait_time_in_seconds: int, output_validator: OutputValidator):
+        start_time = time.perf_counter()
+        while True:
+            assert not self.cluster.segfault_happened() or self.cluster.log_app_output()
+            if output_validator.validate():
+                return
+            time.sleep(1)
+            if wait_time_in_seconds < (time.perf_counter() - start_time):
+                break
+        assert output_validator.validate() or self.cluster.log_app_output()
+
     def __check_output(self, timeout_seconds, output_validator, max_files=0):
         result = self.file_system_observer.validate_output(timeout_seconds, output_validator, max_files)
         assert not self.cluster.segfault_happened() or self.cluster.log_app_output()
@@ -387,6 +417,24 @@ class MiNiFi_integration_test:
     def enable_sql_in_minifi(self):
         self.cluster.enable_sql_in_minifi()
 
+    def enable_ssl_in_grafana_loki(self):
+        self.cluster.enable_ssl_in_grafana_loki()
+
+    def enable_multi_tenancy_in_grafana_loki(self):
+        self.cluster.enable_multi_tenancy_in_grafana_loki()
+
+    def use_nifi_python_processors_with_system_python_packages_installed_in_minifi(self):
+        self.cluster.use_nifi_python_processors_with_system_python_packages_installed_in_minifi()
+
+    def use_nifi_python_processors_with_virtualenv_in_minifi(self):
+        self.cluster.use_nifi_python_processors_with_virtualenv_in_minifi()
+
+    def use_nifi_python_processors_with_virtualenv_packages_installed_in_minifi(self):
+        self.cluster.use_nifi_python_processors_with_virtualenv_packages_installed_in_minifi()
+
+    def remove_python_requirements_txt_in_minifi(self):
+        self.cluster.remove_python_requirements_txt_in_minifi()
+
     def set_yaml_in_minifi(self):
         self.cluster.set_yaml_in_minifi()
 
@@ -425,3 +473,12 @@ class MiNiFi_integration_test:
 
     def enable_log_metrics_publisher_in_minifi(self):
         self.cluster.enable_log_metrics_publisher_in_minifi()
+
+    def enable_example_minifi_python_processors(self):
+        self.cluster.enable_example_minifi_python_processors()
+
+    def debug_bundle_can_be_retrieved_through_minifi_controller(self, container_name: str):
+        assert self.cluster.debug_bundle_can_be_retrieved_through_minifi_controller(container_name) or self.cluster.log_app_output()
+
+    def check_lines_on_grafana_loki(self, lines: List[str], timeout_seconds: int, ssl: bool, tenant_id=None):
+        assert self.cluster.wait_for_lines_on_grafana_loki(lines, timeout_seconds, ssl, tenant_id) or self.cluster.log_app_output()
