@@ -321,6 +321,7 @@ def step_impl(context, processor_name):
 def step_impl(context, source_name):
     remote_process_group = context.test.get_remote_process_group_by_name("RemoteProcessGroup")
     source = context.test.generate_input_port_for_remote_process_group(remote_process_group, source_name)
+    source.instance_id = context.test.get_node_by_name("to_nifi").instance_id
     context.test.add_node(source)
     container = context.test.acquire_container(context=context, name='nifi', engine='nifi')
     # Assume that the first node declared is primary unless specified otherwise
@@ -423,11 +424,13 @@ def step_impl(context):
 
 
 # MQTT setup
+@when("an MQTT broker is set up in correspondence with the PublishMQTT")
 @given("an MQTT broker is set up in correspondence with the PublishMQTT")
 @given("an MQTT broker is set up in correspondence with the ConsumeMQTT")
 @given("an MQTT broker is set up in correspondence with the PublishMQTT and ConsumeMQTT")
 def step_impl(context):
     context.test.acquire_container(context=context, name="mqtt-broker", engine="mqtt-broker")
+    context.test.start('mqtt-broker')
 
 
 # s3 setup
@@ -477,17 +480,21 @@ def step_impl(context):
     context.test.create_doc_elasticsearch(context.test.get_container_name_with_postfix("opensearch"), "my_index", "preloaded_id")
 
 
-@given(u'a SSL context service is set up for PostElasticsearch and Elasticsearch')
-def step_impl(context):
+def setUpSslContextServiceForProcessor(context, processor_name: str):
     minifi_crt_file = '/tmp/resources/minifi_client.crt'
     minifi_key_file = '/tmp/resources/minifi_client.key'
     root_ca_crt_file = '/tmp/resources/root_ca.crt'
     ssl_context_service = SSLContextService(cert=minifi_crt_file, ca_cert=root_ca_crt_file, key=minifi_key_file)
-    post_elasticsearch_json = context.test.get_node_by_name("PostElasticsearch")
+    post_elasticsearch_json = context.test.get_node_by_name(processor_name)
     post_elasticsearch_json.controller_services.append(ssl_context_service)
     post_elasticsearch_json.set_property("SSL Context Service", ssl_context_service.name)
 
 
+@given(u'a SSL context service is set up for PostElasticsearch and Elasticsearch')
+def step_impl(context):
+    setUpSslContextServiceForProcessor(context, "PostElasticsearch")
+
+
 @given(u'a SSL context service is set up for PostElasticsearch and Opensearch')
 def step_impl(context):
     root_ca_crt_file = '/tmp/resources/root_ca.crt'
@@ -520,6 +527,12 @@ def step_impl(context):
     context.test.start_splunk(context)
 
 
+@given("the Splunk token property is set for the {processor_name} processor")
+def step_impl(context, processor_name):
+    token = context.test.get_splunk_token()
+    context.execute_steps(f"given the \"Token\" property of the {processor_name} processor is set to \"{token}\"")
+
+
 # TCP client
 @given('a TCP client is set up to send a test TCP message to minifi')
 def step_impl(context):
@@ -787,6 +800,7 @@ def step_impl(context, content, duration):
 
 
 @then("at least one flowfile's content match the following regex: \"{regex}\" in less than {duration}")
+@then("at least one flowfile's content match the following regex: '{regex}' in less than {duration}")
 def step_impl(context, regex: str, duration: str):
     context.test.check_for_at_least_one_file_with_matching_content(regex, humanfriendly.parse_timespan(duration))
 
@@ -807,7 +821,12 @@ def step_impl(context, num_flowfiles, duration):
 
 @then("at least one flowfile is placed in the monitored directory in less than {duration}")
 def step_impl(context, duration):
-    context.test.check_for_num_file_range_generated(1, float('inf'), humanfriendly.parse_timespan(duration))
+    context.test.check_for_num_file_range_generated_with_timeout(1, float('inf'), humanfriendly.parse_timespan(duration))
+
+
+@then("at least one flowfile with minimum size of \"{size}\" is placed in the monitored directory in less than {duration}")
+def step_impl(context, duration: str, size: str):
+    context.test.check_for_num_file_range_and_min_size_generated(1, float('inf'), humanfriendly.parse_size(size), humanfriendly.parse_timespan(duration))
 
 
 @then("one flowfile with the contents \"{content}\" is placed in the monitored directory in less than {duration}")
@@ -828,7 +847,7 @@ def step_impl(context, duration, contents):
 
 @then("after a wait of {duration}, at least {lower_bound:d} and at most {upper_bound:d} flowfiles are produced and placed in the monitored directory")
 def step_impl(context, lower_bound, upper_bound, duration):
-    context.test.check_for_num_file_range_generated(lower_bound, upper_bound, humanfriendly.parse_timespan(duration))
+    context.test.check_for_num_file_range_generated_after_wait(lower_bound, upper_bound, humanfriendly.parse_timespan(duration))
 
 
 @then("{number_of_files:d} flowfiles are placed in the monitored directory in {duration}")
@@ -957,17 +976,6 @@ def step_impl(context, minifi_container_name, log_pattern, duration):
     context.test.check_container_log_matches_regex(minifi_container_name, log_pattern, humanfriendly.parse_timespan(duration), count=1)
 
 
-@then("an MQTT broker is deployed in correspondence with the PublishMQTT")
-def step_impl(context):
-    context.test.acquire_container(context=context, name="mqtt-broker", engine="mqtt-broker")
-    context.test.start()
-
-
-@when("the MQTT broker is started")
-def step_impl(context):
-    context.test.start('mqtt-broker')
-
-
 # Google Cloud Storage
 @then('an object with the content \"{content}\" is present in the Google Cloud storage')
 def step_imp(context, content):
@@ -1046,7 +1054,7 @@ def step_impl(context):
     context.test.enable_c2_with_ssl_in_minifi()
 
 
-@given("a ssl properties are set up for MiNiFi C2 server")
+@given("ssl properties are set up for MiNiFi C2 server")
 def step_impl(context):
     context.test.enable_c2_with_ssl_in_minifi()
     context.test.set_ssl_context_properties_in_minifi()
@@ -1208,3 +1216,81 @@ def step_impl(context, minifi_container_name: str):
 @then(u'manifest can be retrieved through MiNiFi controller')
 def step_impl(context):
     context.execute_steps(f"then manifest can be retrieved through MiNiFi controller in the \"minifi-cpp-flow-{context.feature_id}\" flow")
+
+
+@then(u'debug bundle can be retrieved through MiNiFi controller in the \"{minifi_container_name}\" flow')
+def step_impl(context, minifi_container_name: str):
+    context.test.debug_bundle_can_be_retrieved_through_minifi_controller(minifi_container_name)
+
+
+@then(u'debug bundle can be retrieved through MiNiFi controller')
+def step_impl(context):
+    context.execute_steps(f"then debug bundle can be retrieved through MiNiFi controller in the \"minifi-cpp-flow-{context.feature_id}\" flow")
+
+
+# Grafana Loki
+@given("a Grafana Loki server is set up")
+def step_impl(context):
+    context.test.acquire_container(context=context, name="grafana-loki-server", engine="grafana-loki-server")
+
+
+@given("a Grafana Loki server with SSL is set up")
+def step_impl(context):
+    context.test.enable_ssl_in_grafana_loki()
+    context.test.acquire_container(context=context, name="grafana-loki-server", engine="grafana-loki-server")
+
+
+@given("a Grafana Loki server is set up with multi-tenancy enabled")
+def step_impl(context):
+    context.test.enable_multi_tenancy_in_grafana_loki()
+    context.test.acquire_container(context=context, name="grafana-loki-server", engine="grafana-loki-server")
+
+
+@then("\"{lines}\" lines are published to the Grafana Loki server in less than {timeout_seconds:d} seconds")
+@then("\"{lines}\" line is published to the Grafana Loki server in less than {timeout_seconds:d} seconds")
+def step_impl(context, lines: str, timeout_seconds: int):
+    context.test.check_lines_on_grafana_loki(lines.split(";"), timeout_seconds, False)
+
+
+@then("\"{lines}\" lines are published to the \"{tenant_id}\" tenant on the Grafana Loki server in less than {timeout_seconds:d} seconds")
+@then("\"{lines}\" line is published to the \"{tenant_id}\" tenant on the Grafana Loki server in less than {timeout_seconds:d} seconds")
+def step_impl(context, lines: str, tenant_id: str, timeout_seconds: int):
+    context.test.check_lines_on_grafana_loki(lines.split(";"), timeout_seconds, False, tenant_id)
+
+
+@then("\"{lines}\" lines are published using SSL to the Grafana Loki server in less than {timeout_seconds:d} seconds")
+@then("\"{lines}\" line is published using SSL to the Grafana Loki server in less than {timeout_seconds:d} seconds")
+def step_impl(context, lines: str, timeout_seconds: int):
+    context.test.check_lines_on_grafana_loki(lines.split(";"), timeout_seconds, True)
+
+
+@given(u'a SSL context service is set up for Grafana Loki processor \"{processor_name}\"')
+@given(u'a SSL context service is set up for the following processor: \"{processor_name}\"')
+def step_impl(context, processor_name: str):
+    setUpSslContextServiceForProcessor(context, processor_name)
+
+
+# Nginx reverse proxy
+@given(u'a reverse proxy is set up to forward requests to the Grafana Loki server')
+def step_impl(context):
+    context.test.acquire_container(context=context, name="reverse-proxy", engine="reverse-proxy")
+
+
+# Python
+@given("python is installed on the MiNiFi agent {install_mode}")
+def step_impl(context, install_mode):
+    if install_mode == "with required python packages":
+        context.test.use_nifi_python_processors_with_system_python_packages_installed_in_minifi()
+    elif install_mode == "with a pre-created virtualenv":
+        context.test.use_nifi_python_processors_with_virtualenv_in_minifi()
+    elif install_mode == "with a pre-created virtualenv containing the required python packages":
+        context.test.use_nifi_python_processors_with_virtualenv_packages_installed_in_minifi()
+    elif install_mode == "using inline defined Python dependencies to install packages":
+        context.test.remove_python_requirements_txt_in_minifi()
+    else:
+        raise Exception("Unknown python install mode.")
+
+
+@given("the example MiNiFi python processors are present")
+def step_impl(context):
+    context.test.enable_example_minifi_python_processors()
