@@ -18,8 +18,9 @@ from ..core.Processor import Processor
 
 
 class GenerateFlowFile(Processor):
-    def __init__(self, schedule={'scheduling period': '2 sec'}):
+    def __init__(self, context, schedule={'scheduling period': '2 sec'}):
         super(GenerateFlowFile, self).__init__(
-            'GenerateFlowFile',
+            context=context,
+            clazz='GenerateFlowFile',
             schedule=schedule,
             auto_terminate=['success'])
