@@ -24,8 +24,7 @@ class QuerySplunkIndexingStatus(Processor):
             clazz='QuerySplunkIndexingStatus',
             properties={
                 'Hostname': 'splunk',
-                'Port': '8088',
-                'Token': 'Splunk 176fae97-f59d-4f08-939a-aa6a543f2485'
+                'Port': '8088'
             },
             auto_terminate=['acknowledged', 'unacknowledged', 'undetermined', 'failure'],
             schedule=schedule)
