@@ -18,8 +18,9 @@ from ..core.Processor import Processor
 
 
 class UpdateAttribute(Processor):
-    def __init__(self, schedule={'scheduling strategy': 'EVENT_DRIVEN'}):
+    def __init__(self, context, schedule={'scheduling strategy': 'EVENT_DRIVEN'}):
         super(UpdateAttribute, self).__init__(
-            'UpdateAttribute',
+            context=context,
+            clazz='UpdateAttribute',
             auto_terminate=['success'],
             schedule=schedule)
