@@ -68,7 +68,7 @@ bool operator!=(const  ConfigFile& left, const  ConfigFile& right) { return !(le
 }  // namespace org::apache::nifi::minifi
 
 TEST_CASE("ConfigFileEncryptor can encrypt the sensitive properties", "[encrypt-config][encryptSensitivePropertiesInFile]") {
-  utils::crypto::Bytes KEY = utils::StringUtils::from_base64("6q9u8LEDy1/CdmSBm8oSqPS/Ds5UOD2nRouP8yUoK10=");
+  utils::crypto::Bytes KEY = utils::string::from_base64("6q9u8LEDy1/CdmSBm8oSqPS/Ds5UOD2nRouP8yUoK10=");
 
   SECTION("default properties") {
     ConfigFile test_file{std::ifstream{"resources/minifi.properties"}};
@@ -77,10 +77,10 @@ TEST_CASE("ConfigFileEncryptor can encrypt the sensitive properties", "[encrypt-
     uint32_t num_properties_encrypted = encryptSensitivePropertiesInFile(test_file, KEY);
 
     REQUIRE(num_properties_encrypted == 1);
-    REQUIRE(test_file.size() == 110);
+    REQUIRE(test_file.size() == 115);
     REQUIRE(check_encryption(test_file, Configuration::nifi_rest_api_password, original_password.length()));
 
-    SECTION("calling encryptSensitiveProperties a second time does nothing") {
+    SECTION("calling encryptSensitiveValuesInMinifiProperties a second time does nothing") {
       ConfigFile test_file_copy = test_file;
 
       uint32_t num_properties_encrypted = encryptSensitivePropertiesInFile(test_file, KEY);
