@@ -51,10 +51,13 @@ class AzureBlobStorageProcessorBase : public AzureStorageProcessorBase {
       .withDescription("The storage account key. This is an admin-like password providing access to every container in this account. "
           "It is recommended one uses Shared Access Signature (SAS) token instead for fine-grained control with policies.")
       .supportsExpressionLanguage(true)
+      .isSensitive(true)
       .build();
   EXTENSIONAPI static constexpr auto SASToken = core::PropertyDefinitionBuilder<>::createProperty("SAS Token")
       .withDescription("Shared Access Signature token. Specify either SAS Token (recommended) or Storage Account Key together with Storage Account Name if Managed Identity is not used.")
-      .supportsExpressionLanguage(true).build();
+      .supportsExpressionLanguage(true)
+      .isSensitive(true)
+      .build();
   EXTENSIONAPI static constexpr auto CommonStorageAccountEndpointSuffix = core::PropertyDefinitionBuilder<>::createProperty("Common Storage Account Endpoint Suffix")
       .withDescription("Storage accounts in public Azure always use a common FQDN suffix. Override this endpoint suffix with a "
           "different suffix in certain circumstances (like Azure Stack or non-public Azure regions). ")
@@ -81,26 +84,26 @@ class AzureBlobStorageProcessorBase : public AzureStorageProcessorBase {
   });
 
 
-  void onSchedule(const std::shared_ptr<core::ProcessContext> &context, const std::shared_ptr<core::ProcessSessionFactory> &sessionFactory) override;
+  void onSchedule(core::ProcessContext& context, core::ProcessSessionFactory& session_factory) override;
 
  protected:
   explicit AzureBlobStorageProcessorBase(
-    std::string name,
+    std::string_view name,
     const minifi::utils::Identifier& uuid,
     const std::shared_ptr<core::logging::Logger>& logger,
     std::unique_ptr<storage::BlobStorageClient> blob_storage_client)
-    : AzureStorageProcessorBase(std::move(name), uuid, logger),
+    : AzureStorageProcessorBase(name, uuid, logger),
       azure_blob_storage_(std::move(blob_storage_client)) {
   }
 
   storage::AzureStorageCredentials getAzureCredentialsFromProperties(
-    core::ProcessContext &context, const std::shared_ptr<core::FlowFile> &flow_file) const;
+    core::ProcessContext &context, const core::FlowFile* const flow_file) const;
   std::optional<storage::AzureStorageCredentials> getCredentials(
-    core::ProcessContext &context, const std::shared_ptr<core::FlowFile> &flow_file) const;
+    core::ProcessContext &context, const core::FlowFile* const flow_file) const;
   bool setCommonStorageParameters(
     storage::AzureBlobStorageParameters& params,
     core::ProcessContext &context,
-    const std::shared_ptr<core::FlowFile> &flow_file);
+    const core::FlowFile* const flow_file);
 
   storage::AzureBlobStorage azure_blob_storage_;
   bool use_managed_identity_credentials_ = false;
