@@ -49,8 +49,8 @@ class ListenHTTP : public core::Processor {
  public:
   using FlowFileBufferPair = std::pair<std::shared_ptr<FlowFileRecord>, std::unique_ptr<io::BufferStream>>;
 
-  explicit ListenHTTP(std::string name, const utils::Identifier& uuid = {})
-      : Processor(std::move(name), uuid) {
+  explicit ListenHTTP(std::string_view name, const utils::Identifier& uuid = {})
+      : Processor(name, uuid) {
     callbacks_.log_message = &logMessage;
     callbacks_.log_access = &logAccess;
   }
@@ -131,21 +131,21 @@ class ListenHTTP : public core::Processor {
 
   EXTENSIONAPI static constexpr bool SupportsDynamicProperties = false;
   EXTENSIONAPI static constexpr bool SupportsDynamicRelationships = false;
-  EXTENSIONAPI static constexpr core::annotation::Input InputRequirement = core::annotation::Input::INPUT_FORBIDDEN;
+  EXTENSIONAPI static constexpr core::annotation::Input InputRequirement = core::annotation::Input::INPUT_ALLOWED;
   EXTENSIONAPI static constexpr bool IsSingleThreaded = false;
 
   ADD_COMMON_VIRTUAL_FUNCTIONS_FOR_PROCESSORS
 
-  void onTrigger(core::ProcessContext *context, core::ProcessSession *session) override;
+  void onTrigger(core::ProcessContext& context, core::ProcessSession& session) override;
   void initialize() override;
-  void onSchedule(core::ProcessContext *context, core::ProcessSessionFactory *sessionFactory) override;
+  void onSchedule(core::ProcessContext& context, core::ProcessSessionFactory& session_factory) override;
   std::string getPort() const;
   bool isSecure() const;
 
   struct ResponseBody {
     std::string uri;
     std::string mime_type;
-    std::string body;
+    std::vector<std::byte> body;
   };
 
   // HTTP request handler
@@ -173,7 +173,7 @@ class ListenHTTP : public core::Processor {
     static void sendHttp500(struct mg_connection *conn);
     static void sendHttp503(struct mg_connection *conn);
     bool authRequest(mg_connection *conn, const mg_request_info *req_info) const;
-    void setHeaderAttributes(const mg_request_info *req_info, const std::shared_ptr<core::FlowFile> &flow_file) const;
+    void setHeaderAttributes(const mg_request_info *req_info, core::FlowFile& flow_file) const;
     void writeBody(mg_connection *conn, const mg_request_info *req_info, bool include_payload = true);
     static std::unique_ptr<io::BufferStream> createContentBuffer(struct mg_connection *conn, const struct mg_request_info *req_info);
     void enqueueRequest(mg_connection *conn, const mg_request_info *req_info, std::unique_ptr<io::BufferStream>);
@@ -185,7 +185,7 @@ class ListenHTTP : public core::Processor {
     std::shared_ptr<core::logging::Logger> logger_ = core::logging::LoggerFactory<ListenHTTP>::getLogger();
     std::map<std::string, ResponseBody> response_uri_map_;
     std::mutex uri_map_mutex_;
-    uint64_t buffer_size_;
+    uint64_t buffer_size_ = 0;
     utils::ConcurrentQueue<FlowFileBufferPair> request_buffer_;
   };
 
@@ -201,7 +201,7 @@ class ListenHTTP : public core::Processor {
       if (logger == nullptr) {
         return 0;
       }
-      core::logging::LOG_ERROR((*logger)) << "CivetWeb error: " << message;
+      (*logger)->log_error("CivetWeb error: {}", message);
     } catch (...) {
     }
     return 0;
@@ -219,7 +219,7 @@ class ListenHTTP : public core::Processor {
       if (logger == nullptr) {
         return 0;
       }
-      core::logging::LOG_DEBUG((*logger)) << "CivetWeb access: " << message;
+      (*logger)->log_debug("CivetWeb access: {}", message);
     } catch (...) {
     }
     return 0;
