@@ -17,6 +17,8 @@
  */
 #include "CoapServer.h"
 #include <coap2/coap.h>
+#include <map>
+#include <functional>
 
 namespace org {
 namespace apache {
