@@ -51,15 +51,13 @@ auto getCredentialsService(core::ProcessContext& context) {
 }
 }  // namespace
 
-void PostElasticsearch::onSchedule(const std::shared_ptr<core::ProcessContext>& context, const std::shared_ptr<core::ProcessSessionFactory>&) {
-  gsl_Expects(context);
-
-  context->getProperty(MaxBatchSize, max_batch_size_);
+void PostElasticsearch::onSchedule(core::ProcessContext& context, core::ProcessSessionFactory&) {
+  context.getProperty(MaxBatchSize, max_batch_size_);
   if (max_batch_size_ < 1)
     throw Exception(PROCESS_SCHEDULE_EXCEPTION, "Max Batch Size property is invalid");
 
-  if (auto hosts_str = context->getProperty(Hosts)) {
-    auto hosts = utils::StringUtils::split(*hosts_str, ",");
+  if (auto hosts_str = context.getProperty(Hosts)) {
+    auto hosts = utils::string::split(*hosts_str, ",");
     if (hosts.size() > 1)
       throw Exception(PROCESS_SCHEDULE_EXCEPTION, "Multiple hosts not yet supported");
     host_url_ = hosts[0];
@@ -67,11 +65,11 @@ void PostElasticsearch::onSchedule(const std::shared_ptr<core::ProcessContext>&
     throw Exception(PROCESS_SCHEDULE_EXCEPTION, "Missing or invalid hosts");
   }
 
-  credentials_service_ = getCredentialsService(*context);
+  credentials_service_ = getCredentialsService(context);
   if (!credentials_service_)
     throw Exception(PROCESS_SCHEDULE_EXCEPTION, "Missing Elasticsearch credentials service");
 
-  client_.initialize("POST", host_url_ + "/_bulk", getSSLContextService(*context));
+  client_.initialize(utils::HttpRequestMethod::POST, host_url_ + "/_bulk", getSSLContextService(context));
   client_.setContentType("application/json");
   credentials_service_->authenticateClient(client_);
 }
@@ -92,15 +90,15 @@ class ElasticPayload {
   }
 
   static nonstd::expected<ElasticPayload, std::string> parse(core::ProcessSession& session, core::ProcessContext& context, const std::shared_ptr<core::FlowFile>& flow_file) {
-    auto action = context.getProperty(PostElasticsearch::Action, flow_file);
+    auto action = context.getProperty(PostElasticsearch::Action, flow_file.get());
     if (!action || (action != "index" && action != "create" && action != "delete" && action != "update" && action != "upsert"))
       return nonstd::make_unexpected("Missing or invalid action");
 
-    auto index = context.getProperty(PostElasticsearch::Index, flow_file);
+    auto index = context.getProperty(PostElasticsearch::Index, flow_file.get());
     if (!index)
       return nonstd::make_unexpected("Missing index");
 
-    auto id = context.getProperty(PostElasticsearch::Identifier, flow_file);
+    auto id = context.getProperty(PostElasticsearch::Identifier, flow_file.get());
     if (!id && (action == "delete" || action == "update" || action == "upsert"))
       return nonstd::make_unexpected("Identifier is required for DELETE,UPDATE and UPSERT actions");
 
@@ -142,15 +140,15 @@ class ElasticPayload {
   [[nodiscard]] std::string headerString() const {
     rapidjson::Document first_line = rapidjson::Document(rapidjson::kObjectType);
 
-    auto operation_index_key = rapidjson::Value(operation_.data(), operation_.size());
+    auto operation_index_key = rapidjson::Value(operation_.data(), gsl::narrow<rapidjson::SizeType>(operation_.size()));
     first_line.AddMember(operation_index_key, rapidjson::Value{rapidjson::kObjectType}, first_line.GetAllocator());
     auto& operation_request = first_line[operation_.c_str()];
 
-    auto index_json = rapidjson::Value(index_.data(), index_.size());
+    auto index_json = rapidjson::Value(index_.data(), gsl::narrow<rapidjson::SizeType>(index_.size()));
     operation_request.AddMember("_index", index_json, first_line.GetAllocator());
 
     if (id_) {
-      auto id_json = rapidjson::Value(id_->data(), id_->size());
+      auto id_json = rapidjson::Value(id_->data(), gsl::narrow<rapidjson::SizeType>(id_->size()));
       operation_request.AddMember("_id", id_json, first_line.GetAllocator());
     }
 
@@ -202,7 +200,7 @@ void addAttributesFromResponse(std::string name, rapidjson::Value::ConstMemberIt
   } else if (object->value.IsDouble()) {
     flow_file.addAttribute(name, std::to_string(object->value.GetDouble()));
   } else {
-    core::logging::LoggerFactory<PostElasticsearch>::getLogger()->log_error("Unexpected %s in response json", object->value.GetType());
+    core::logging::LoggerFactory<PostElasticsearch>::getLogger()->log_error("Unexpected {} in response json", magic_enum::enum_underlying(object->value.GetType()));
   }
 }
 
@@ -211,7 +209,7 @@ void processResponseFromElastic(const rapidjson::Document& response, core::Proce
   auto& items = response["items"];
   gsl_Expects(items.IsArray());
   gsl_Expects(items.Size() == flowfiles_sent.size());
-  for (size_t i = 0; i < items.Size(); ++i) {
+  for (rapidjson::SizeType i = 0; i < items.Size(); ++i) {
     gsl_Expects(items[i].IsObject());
     for (auto it = items[i].MemberBegin(); it != items[i].MemberEnd(); ++it) {
       addAttributesFromResponse("elasticsearch", it, *flowfiles_sent[i]);
@@ -234,7 +232,7 @@ std::string PostElasticsearch::collectPayload(core::ProcessContext& context,
       break;
     auto elastic_payload = ElasticPayload::parse(session, context, flow_file);
     if (!elastic_payload) {
-      logger_->log_error(elastic_payload.error().c_str());
+      logger_->log_error("{}", elastic_payload.error());
       session.transfer(flow_file, PostElasticsearch::Failure);
       continue;
     }
@@ -245,11 +243,11 @@ std::string PostElasticsearch::collectPayload(core::ProcessContext& context,
   return payload.str();
 }
 
-void PostElasticsearch::onTrigger(const std::shared_ptr<core::ProcessContext>& context, const std::shared_ptr<core::ProcessSession>& session) {
-  gsl_Expects(context && session && max_batch_size_ > 0);
+void PostElasticsearch::onTrigger(core::ProcessContext& context, core::ProcessSession& session) {
+  gsl_Expects(max_batch_size_ > 0);
 
   std::vector<std::shared_ptr<core::FlowFile>> flowfiles_with_payload;
-  auto payload = collectPayload(*context, *session, flowfiles_with_payload);
+  auto payload = collectPayload(context, session, flowfiles_with_payload);
 
   if (flowfiles_with_payload.empty()) {
     return;
@@ -257,13 +255,13 @@ void PostElasticsearch::onTrigger(const std::shared_ptr<core::ProcessContext>& c
 
   auto result = submitRequest(client_, payload, flowfiles_with_payload.size());
   if (!result) {
-    logger_->log_error(result.error().c_str());
+    logger_->log_error("{}", result.error());
     for (const auto& flow_file_in_payload: flowfiles_with_payload)
-      session->transfer(flow_file_in_payload, Failure);
+      session.transfer(flow_file_in_payload, Failure);
     return;
   }
 
-  processResponseFromElastic(*result, *session, flowfiles_with_payload);
+  processResponseFromElastic(*result, session, flowfiles_with_payload);
 }
 
 REGISTER_RESOURCE(PostElasticsearch, Processor);
