@@ -15,6 +15,7 @@
  * limitations under the License.
  */
 
+#include <atomic>
 #include <chrono>
 #include <utility>
 #include <iostream>
@@ -34,7 +35,7 @@
 #include "expression/Expression.h"
 #include "utils/RegexUtils.h"
 
-#ifndef DISABLE_CURL
+#ifdef ENABLE_CURL
 #ifdef WIN32
 #pragma comment(lib, "wldap32.lib" )
 #pragma comment(lib, "crypt32.lib" )
@@ -92,7 +93,7 @@ Expression make_dynamic(const std::function<Value(const Parameters &params, cons
 Expression make_dynamic_attr(const std::string &attribute_id) {
   return make_dynamic([attribute_id](const Parameters &params, const std::vector<Expression>& /*sub_exprs*/) -> Value {
     std::string result;
-    const auto cur_flow_file = params.flow_file.lock();
+    const auto cur_flow_file = params.flow_file;
     if (cur_flow_file && cur_flow_file->getAttribute(attribute_id, result)) {
       return Value(result);
     } else {
@@ -118,21 +119,19 @@ Value resolve_user_id(const std::vector<Value> &args) {
 }
 
 Value expr_hostname(const std::vector<Value> &args) {
-  char hostname[1024];
-  hostname[1023] = '\0';
-  gethostname(hostname, 1023);
+  std::array<char, 1024> hostname{};
+  gethostname(hostname.data(), 1023);
 
   if (!args.empty() && args[0].asBoolean()) {
-    int status;
-    struct addrinfo hints;
-    struct addrinfo *result;
-    struct addrinfo *addr_cursor;
-    memset(&hints, 0, sizeof(hints));
+    int status = 0;
+    struct addrinfo hints{};
+    struct addrinfo *result = nullptr;
+    struct addrinfo *addr_cursor = nullptr;
     hints.ai_family = AF_UNSPEC;
     hints.ai_socktype = SOCK_STREAM;
     hints.ai_flags = AI_CANONNAME;
 
-    status = getaddrinfo(hostname, nullptr, &hints, &result);
+    status = getaddrinfo(hostname.data(), nullptr, &hints, &result);
 
     if (status) {
       std::string message("Failed to resolve local hostname to discover IP: ");
@@ -151,24 +150,22 @@ Value expr_hostname(const std::vector<Value> &args) {
     freeaddrinfo(result);
   }
 
-  return Value(std::string(hostname));
+  return Value(std::string(hostname.data()));
 }
 
 Value expr_ip(const std::vector<Value>& /*args*/) {
-  char hostname[1024];
-  hostname[1023] = '\0';
-  gethostname(hostname, 1023);
+  std::array<char, 1024> hostname{};
+  gethostname(hostname.data(), 1023);
 
-  int status;
-  char ip_str[INET6_ADDRSTRLEN];
-  struct sockaddr_in *addr;
-  struct addrinfo hints;
-  struct addrinfo *result;
-  struct addrinfo *addr_cursor;
-  memset(&hints, 0, sizeof(hints));
+  int status = 0;
+  std::array<char, INET6_ADDRSTRLEN> ip_str{};
+  struct sockaddr_in *addr = nullptr;
+  struct addrinfo hints{};
+  struct addrinfo *result = nullptr;
+  struct addrinfo *addr_cursor = nullptr;
   hints.ai_family = AF_INET;
 
-  status = getaddrinfo(hostname, nullptr, &hints, &result);
+  status = getaddrinfo(hostname.data(), nullptr, &hints, &result);
 
   if (status) {
     std::string message("Failed to resolve local hostname to discover IP: ");
@@ -179,9 +176,9 @@ Value expr_ip(const std::vector<Value>& /*args*/) {
   for (addr_cursor = result; addr_cursor != nullptr; addr_cursor = addr_cursor->ai_next) {
     if (addr_cursor->ai_family == AF_INET) {
       addr = reinterpret_cast<struct sockaddr_in *>(addr_cursor->ai_addr);
-      inet_ntop(addr_cursor->ai_family, &(addr->sin_addr), ip_str, sizeof(ip_str));
+      inet_ntop(addr_cursor->ai_family, &(addr->sin_addr), ip_str.data(), ip_str.size());
       freeaddrinfo(result);
-      return Value(std::string(ip_str));
+      return Value(std::string(ip_str.data()));
     }
   }
 
@@ -198,8 +195,8 @@ Value expr_reverseDnsLookup(const std::vector<Value>& args) {
   }
 
   return utils::net::addressFromString(ip_address_str)
-      | utils::flatMap([timeout_duration](const auto& ip_address) { return utils::net::reverseDnsLookup(ip_address, timeout_duration);})
-      | utils::map([](const auto& hostname)-> Value { return Value(hostname); })
+      | utils::andThen([timeout_duration](const auto& ip_address) { return utils::net::reverseDnsLookup(ip_address, timeout_duration);})
+      | utils::transform([](const auto& hostname)-> Value { return Value(hostname); })
       | utils::valueOrElse([&](std::error_code error_code) {
         if (error_code.value() == asio::error::timed_out) {
           core::logging::LoggerFactory<Expression>::getLogger()->log_warn("reverseDnsLookup timed out");
@@ -465,7 +462,7 @@ Value expr_unescapeJson(const std::vector<Value> &args) {
 }
 
 Value expr_escapeHtml3(const std::vector<Value> &args) {
-  return Value(utils::StringUtils::replaceMap(args[0].asString(), { { "!", "&excl;" }, { "\"", "&quot;" }, { "#", "&num;" }, { "$", "&dollar;" }, { "%", "&percnt;" }, { "&", "&amp;" },
+  return Value(utils::string::replaceMap(args[0].asString(), { { "!", "&excl;" }, { "\"", "&quot;" }, { "#", "&num;" }, { "$", "&dollar;" }, { "%", "&percnt;" }, { "&", "&amp;" },
                                                   { "'", "&apos;" }, { "(", "&lpar;" }, { ")", "&rpar;" }, { "*", "&ast;" }, { "+", "&plus;" }, { ",", "&comma;" }, { "-", "&minus;" }, { ".",
                                                       "&period;" }, { "/", "&sol;" }, { ":", "&colon;" }, { ";", "&semi;" }, { "<", "&lt;" }, { "=", "&equals;" }, { ">", "&gt;" }, { "?", "&quest;" },
                                                   { "@", "&commat;" }, { "[", "&lsqb;" }, { "\\", "&bsol;" }, { "]", "&rsqb;" }, { "^", "&circ;" }, { "_", "&lowbar;" }, { "`", "&grave;" }, { "{",
@@ -486,7 +483,7 @@ Value expr_escapeHtml3(const std::vector<Value> &args) {
 }
 
 Value expr_escapeHtml4(const std::vector<Value> &args) {
-  return Value(utils::StringUtils::replaceMap(args[0].asString(), { { "!", "&excl;" }, { "\"", "&quot;" }, { "#", "&num;" }, { "$", "&dollar;" }, { "%", "&percnt;" }, { "&", "&amp;" },
+  return Value(utils::string::replaceMap(args[0].asString(), { { "!", "&excl;" }, { "\"", "&quot;" }, { "#", "&num;" }, { "$", "&dollar;" }, { "%", "&percnt;" }, { "&", "&amp;" },
                                                   { "'", "&apos;" }, { "(", "&lpar;" }, { ")", "&rpar;" }, { "*", "&ast;" }, { "+", "&plus;" }, { ",", "&comma;" }, { "-", "&minus;" }, { ".",
                                                       "&period;" }, { "/", "&sol;" }, { ":", "&colon;" }, { ";", "&semi;" }, { "<", "&lt;" }, { "=", "&equals;" }, { ">", "&gt;" }, { "?", "&quest;" },
                                                   { "@", "&commat;" }, { "[", "&lsqb;" }, { "\\", "&bsol;" }, { "]", "&rsqb;" }, { "^", "&circ;" }, { "_", "&lowbar;" }, { "`", "&grave;" }, { "{",
@@ -534,7 +531,7 @@ Value expr_escapeHtml4(const std::vector<Value> &args) {
 }
 
 Value expr_unescapeHtml3(const std::vector<Value> &args) {
-  return Value(utils::StringUtils::replaceMap(args[0].asString(), { { "&excl;", "!" }, { "&quot;", "\"" }, { "&num;", "#" }, { "&dollar;", "$" }, { "&percnt;", "%" }, { "&amp;", "&" },
+  return Value(utils::string::replaceMap(args[0].asString(), { { "&excl;", "!" }, { "&quot;", "\"" }, { "&num;", "#" }, { "&dollar;", "$" }, { "&percnt;", "%" }, { "&amp;", "&" },
                                                   { "&apos;", "'" }, { "&lpar;", "(" }, { "&rpar;", ")" }, { "&ast;", "*" }, { "&plus;", "+" }, { "&comma;", "," }, { "&minus;", "-" }, { "&period;",
                                                       "." }, { "&sol;", "/" }, { "&colon;", ":" }, { "&semi;", ";" }, { "&lt;", "<" }, { "&equals;", "=" }, { "&gt;", ">" }, { "&quest;", "?" }, {
                                                       "&commat;", "@" }, { "&lsqb;", "[" }, { "&bsol;", "\\" }, { "&rsqb;", "]" }, { "&circ;", "^" }, { "&lowbar;", "_" }, { "&grave;", "`" }, {
@@ -555,7 +552,7 @@ Value expr_unescapeHtml3(const std::vector<Value> &args) {
 }
 
 Value expr_unescapeHtml4(const std::vector<Value> &args) {
-  return Value(utils::StringUtils::replaceMap(args[0].asString(), { { "&excl;", "!" }, { "&quot;", "\"" }, { "&num;", "#" }, { "&dollar;", "$" }, { "&percnt;", "%" }, { "&amp;", "&" },
+  return Value(utils::string::replaceMap(args[0].asString(), { { "&excl;", "!" }, { "&quot;", "\"" }, { "&num;", "#" }, { "&dollar;", "$" }, { "&percnt;", "%" }, { "&amp;", "&" },
                                                   { "&apos;", "'" }, { "&lpar;", "(" }, { "&rpar;", ")" }, { "&ast;", "*" }, { "&plus;", "+" }, { "&comma;", "," }, { "&minus;", "-" }, { "&period;",
                                                       "." }, { "&sol;", "/" }, { "&colon;", ":" }, { "&semi;", ";" }, { "&lt;", "<" }, { "&equals;", "=" }, { "&gt;", ">" }, { "&quest;", "?" }, {
                                                       "&commat;", "@" }, { "&lsqb;", "[" }, { "&bsol;", "\\" }, { "&rsqb;", "]" }, { "&circ;", "^" }, { "&lowbar;", "_" }, { "&grave;", "`" }, {
@@ -603,16 +600,16 @@ Value expr_unescapeHtml4(const std::vector<Value> &args) {
 }
 
 Value expr_escapeXml(const std::vector<Value> &args) {
-  return Value(utils::StringUtils::replaceMap(args[0].asString(), { { "\"", "&quot;" }, { "'", "&apos;" }, { "<", "&lt;" }, { ">", "&gt;" }, { "&", "&amp;" } }));
+  return Value(utils::string::replaceMap(args[0].asString(), { { "\"", "&quot;" }, { "'", "&apos;" }, { "<", "&lt;" }, { ">", "&gt;" }, { "&", "&amp;" } }));
 }
 
 Value expr_unescapeXml(const std::vector<Value> &args) {
-  return Value(utils::StringUtils::replaceMap(args[0].asString(), { { "&quot;", "\"" }, { "&apos;", "'" }, { "&lt;", "<" }, { "&gt;", ">" }, { "&amp;", "&" } }));
+  return Value(utils::string::replaceMap(args[0].asString(), { { "&quot;", "\"" }, { "&apos;", "'" }, { "&lt;", "<" }, { "&gt;", ">" }, { "&amp;", "&" } }));
 }
 
 Value expr_escapeCsv(const std::vector<Value> &args) {
   auto result = args[0].asString();
-  const char quote_req_chars[] = { '"', '\r', '\n', ',' };
+  const std::array<char, 4> quote_req_chars = { '"', '\r', '\n', ',' };
   bool quote_required = false;
 
   for (const auto &c : quote_req_chars) {
@@ -624,7 +621,7 @@ Value expr_escapeCsv(const std::vector<Value> &args) {
 
   if (quote_required) {
     std::string quoted_result = "\"";
-    quoted_result.append(utils::StringUtils::replaceMap(result, { { "\"", "\"\"" } }));
+    quoted_result.append(utils::string::replaceMap(result, { { "\"", "\"\"" } }));
     quoted_result.append("\"");
     return Value(quoted_result);
   }
@@ -686,7 +683,7 @@ Value expr_unescapeCsv(const std::vector<Value> &args) {
     if (quote_pos != result.length() - 1) {
       quote_required = true;
     } else {
-      const char quote_req_chars[] = { '\r', '\n', ',' };
+      const std::array<char, 3> quote_req_chars = { '\r', '\n', ',' };
 
       for (const auto &c : quote_req_chars) {
         if (result.find(c) != std::string::npos) {
@@ -697,7 +694,7 @@ Value expr_unescapeCsv(const std::vector<Value> &args) {
     }
 
     if (quote_required) {
-      return Value(utils::StringUtils::replaceMap(result.substr(1, result.size() - 2), { { "\"\"", "\"" } }));
+      return Value(utils::string::replaceMap(result.substr(1, result.size() - 2), { { "\"\"", "\"" } }));
     }
   }
 
@@ -705,7 +702,7 @@ Value expr_unescapeCsv(const std::vector<Value> &args) {
 }
 
 Value expr_urlEncode(const std::vector<Value> &args) {
-#ifndef DISABLE_CURL
+#ifdef ENABLE_CURL
   auto arg_0 = args[0].asString();
   CURL *curl = curl_easy_init();
   if (curl != nullptr) {
@@ -728,11 +725,11 @@ Value expr_urlEncode(const std::vector<Value> &args) {
 }
 
 Value expr_urlDecode(const std::vector<Value> &args) {
-#ifndef DISABLE_CURL
+#ifdef ENABLE_CURL
   auto arg_0 = args[0].asString();
   CURL *curl = curl_easy_init();
   if (curl != nullptr) {
-    int out_len;
+    int out_len = 0;
     char *output = curl_easy_unescape(curl, arg_0.c_str(), static_cast<int>(arg_0.length()), &out_len);
     if (output != nullptr) {
       auto result = std::string(output, static_cast<size_t>(out_len));
@@ -752,11 +749,11 @@ Value expr_urlDecode(const std::vector<Value> &args) {
 }
 
 Value expr_base64Encode(const std::vector<Value> &args) {
-  return Value(utils::StringUtils::to_base64(args[0].asString()));
+  return Value(utils::string::to_base64(args[0].asString()));
 }
 
 Value expr_base64Decode(const std::vector<Value> &args) {
-  return Value(utils::StringUtils::from_base64(args[0].asString(), utils::as_string));
+  return Value(utils::string::from_base64(args[0].asString(), utils::as_string));
 }
 
 Value expr_replace(const std::vector<Value> &args) {
@@ -819,7 +816,7 @@ Value expr_find(const std::vector<Value> &args) {
 }
 
 Value expr_trim(const std::vector<Value> &args) {
-  return Value{utils::StringUtils::trim(args[0].asString())};
+  return Value{utils::string::trim(args[0].asString())};
 }
 
 Value expr_append(const std::vector<Value> &args) {
@@ -891,9 +888,8 @@ Value expr_toRadix(const std::vector<Value> &args) {
     sign = "-";
   }
 
-  const char chars[] = "0123456789ab"
-      "cdefghijklmn"
-      "opqrstuvwxyz";
+  const std::array<char, 36> chars = { '0', '1', '2', '3', '4', '5', '6', '7', '8', '9', 'a', 'b', 'c', 'd', 'e', 'f', 'g', 'h',
+    'i', 'j', 'k', 'l', 'm', 'n', 'o', 'p', 'q', 'r', 's', 't', 'u', 'v', 'w', 'x', 'y', 'z' };
   std::string str_num;
 
   while (value) {
@@ -1051,6 +1047,11 @@ Value expr_ifElse(const std::vector<Value> &args) {
   }
 }
 
+Value expr_nextInt(const std::vector<Value>&) {
+  static std::atomic<int64_t> counter{0};
+  return Value(counter++);
+}
+
 Expression make_allAttributes(const std::string &function_name, const std::vector<Expression> &args) {
   if (args.empty()) {
     std::stringstream message_ss;
@@ -1080,7 +1081,7 @@ Expression make_allAttributes(const std::string &function_name, const std::vecto
                 attr_id = arg(params).asString();
                 std::string attr_val;
 
-                const auto cur_flow_file = params.flow_file.lock();
+                const auto cur_flow_file = params.flow_file;
 
                 if (cur_flow_file && cur_flow_file->getAttribute(attr_id, attr_val)) {
                   return Value(attr_val);
@@ -1125,7 +1126,7 @@ Expression make_anyAttribute(const std::string &function_name, const std::vector
                 attr_id = arg(params).asString();
                 std::string attr_val;
 
-                const auto cur_flow_file = params.flow_file.lock();
+                const auto cur_flow_file = params.flow_file;
 
                 if (cur_flow_file && cur_flow_file->getAttribute(attr_id, attr_val)) {
                   return Value(attr_val);
@@ -1165,7 +1166,7 @@ Expression make_allMatchingAttributes(const std::string &function_name, const st
 
     for (const auto &arg : args) {
       const auto attr_regex = utils::Regex(arg(params).asString());
-      const auto cur_flow_file = params.flow_file.lock();
+      const auto cur_flow_file = params.flow_file;
       std::map<std::string, std::string> attrs;
 
       if (cur_flow_file) {
@@ -1218,7 +1219,7 @@ Expression make_anyMatchingAttribute(const std::string &function_name, const std
 
     for (const auto &arg : args) {
       const auto attr_regex = utils::Regex(arg(params).asString());
-      const auto cur_flow_file = params.flow_file.lock();
+      const auto cur_flow_file = params.flow_file;
       std::map<std::string, std::string> attrs;
 
       if (cur_flow_file) {
@@ -1269,7 +1270,7 @@ Expression make_allDelineatedValues(const std::string &function_name, const std:
   result.make_multi([=](const Parameters &params) -> std::vector<Expression> {
     std::vector<Expression> out_exprs;
 
-    for (const auto &val : utils::StringUtils::split(args[0](params).asString(), args[1](params).asString())) {
+    for (const auto &val : utils::string::split(args[0](params).asString(), args[1](params).asString())) {
       out_exprs.emplace_back(make_static(val));
     }
 
@@ -1301,7 +1302,7 @@ Expression make_anyDelineatedValue(const std::string &function_name, const std::
   result.make_multi([=](const Parameters &params) -> std::vector<Expression> {
     std::vector<Expression> out_exprs;
 
-    for (const auto &val : utils::StringUtils::split(args[0](params).asString(), args[1](params).asString())) {
+    for (const auto &val : utils::string::split(args[0](params).asString(), args[1](params).asString())) {
       out_exprs.emplace_back(make_static(val));
     }
 
@@ -1524,6 +1525,8 @@ Expression make_dynamic_function(const std::string &function_name, const std::ve
     return make_dynamic_function_incomplete<expr_toDate>(function_name, args, 0);
   } else if (function_name == "now") {
     return make_dynamic_function_incomplete<expr_now>(function_name, args, 0);
+  } else if (function_name == "nextInt") {
+    return make_dynamic_function_incomplete<expr_nextInt>(function_name, args, 0);
   } else {
     std::string msg("Unknown expression function: ");
     msg.append(function_name);
