@@ -33,8 +33,8 @@ namespace org::apache::nifi::minifi::extensions::gcp {
 
 class DeleteGCSObject : public GCSProcessor {
  public:
-  explicit DeleteGCSObject(std::string name, const utils::Identifier& uuid = {})
-      : GCSProcessor(std::move(name), uuid, core::logging::LoggerFactory<DeleteGCSObject>::getLogger(uuid)) {
+  explicit DeleteGCSObject(std::string_view name, const utils::Identifier& uuid = {})
+      : GCSProcessor(name, uuid, core::logging::LoggerFactory<DeleteGCSObject>::getLogger(uuid)) {
   }
   ~DeleteGCSObject() override = default;
 
@@ -84,7 +84,7 @@ class DeleteGCSObject : public GCSProcessor {
   ADD_COMMON_VIRTUAL_FUNCTIONS_FOR_PROCESSORS
 
   void initialize() override;
-  void onTrigger(const std::shared_ptr<core::ProcessContext>& context, const std::shared_ptr<core::ProcessSession>& session) override;
+  void onTrigger(core::ProcessContext& context, core::ProcessSession& session) override;
 };
 
 }  // namespace org::apache::nifi::minifi::extensions::gcp
