@@ -73,8 +73,8 @@ namespace org::apache::nifi::minifi::extensions::gcp {
 
 class PutGCSObject : public GCSProcessor {
  public:
-  explicit PutGCSObject(std::string name, const utils::Identifier& uuid = {})
-      : GCSProcessor(std::move(name), uuid, core::logging::LoggerFactory<PutGCSObject>::getLogger(uuid)) {
+  explicit PutGCSObject(std::string_view name, const utils::Identifier& uuid = {})
+      : GCSProcessor(name, uuid, core::logging::LoggerFactory<PutGCSObject>::getLogger(uuid)) {
   }
   ~PutGCSObject() override = default;
 
@@ -110,6 +110,7 @@ class PutGCSObject : public GCSProcessor {
       .withDescription("An AES256 Encryption Key (encoded in base64) for server-side encryption of the object.")
       .isRequired(false)
       .supportsExpressionLanguage(true)
+      .isSensitive(true)
       .build();
   EXTENSIONAPI static constexpr auto ObjectACL = core::PropertyDefinitionBuilder<magic_enum::enum_count<put_gcs_object::PredefinedAcl>()>::createProperty("Object ACL")
       .withDescription("Access Control to be attached to the object uploaded. Not providing this will revert to bucket defaults.")
@@ -196,8 +197,8 @@ class PutGCSObject : public GCSProcessor {
   ADD_COMMON_VIRTUAL_FUNCTIONS_FOR_PROCESSORS
 
   void initialize() override;
-  void onSchedule(const std::shared_ptr<core::ProcessContext> &context, const std::shared_ptr<core::ProcessSessionFactory> &session_factory) override;
-  void onTrigger(const std::shared_ptr<core::ProcessContext>& context, const std::shared_ptr<core::ProcessSession>& session) override;
+  void onSchedule(core::ProcessContext& context, core::ProcessSessionFactory& session_factory) override;
+  void onTrigger(core::ProcessContext& context, core::ProcessSession& session) override;
 
  private:
   google::cloud::storage::EncryptionKey encryption_key_;
