@@ -19,7 +19,6 @@
 #include "InvokeHTTP.h"
 
 #include <cinttypes>
-#include <cstdint>
 #include <memory>
 #include <string>
 #include <utility>
@@ -27,10 +26,8 @@
 
 #include "core/FlowFile.h"
 #include "core/ProcessContext.h"
-#include "core/Relationship.h"
 #include "core/Resource.h"
 #include "io/BufferStream.h"
-#include "ResourceClaim.h"
 #include "utils/gsl.h"
 #include "utils/ProcessorConfigUtils.h"
 #include "utils/OptionalUtils.h"
@@ -48,43 +45,14 @@ void InvokeHTTP::initialize() {
 }
 
 namespace {
-void setupClientTimeouts(extensions::curl::HTTPClient& client, const core::ProcessContext& context) {
-  if (auto connection_timeout = context.getProperty<core::TimePeriodValue>(InvokeHTTP::ConnectTimeout))
-    client.setConnectionTimeout(connection_timeout->getMilliseconds());
+void setupClientTimeouts(extensions::curl::HTTPClient& client,
+    std::optional<std::chrono::milliseconds> connection_timeout,
+    std::optional<std::chrono::milliseconds> read_timeout) {
+  if (connection_timeout)
+    client.setConnectionTimeout(*connection_timeout);
 
-  if (auto read_timeout = context.getProperty<core::TimePeriodValue>(InvokeHTTP::ReadTimeout))
-    client.setReadTimeout(read_timeout->getMilliseconds());
-}
-
-void setupClientProxy(extensions::curl::HTTPClient& client, const core::ProcessContext& context) {
-  utils::HTTPProxy proxy = {};
-  context.getProperty(InvokeHTTP::ProxyHost, proxy.host);
-  std::string port_str;
-  if (context.getProperty(InvokeHTTP::ProxyPort, port_str) && !port_str.empty()) {
-    core::Property::StringToInt(port_str, proxy.port);
-  }
-  context.getProperty(InvokeHTTP::ProxyUsername, proxy.username);
-  context.getProperty(InvokeHTTP::ProxyPassword, proxy.password);
-
-  client.setHTTPProxy(proxy);
-}
-
-void setupClientPeerVerification(extensions::curl::HTTPClient& client, const core::ProcessContext& context) {
-  if (auto disable_peer_verification = context.getProperty(InvokeHTTP::DisablePeerVerification) | utils::flatMap(&utils::StringUtils::toBool)) {
-    client.setPeerVerification(!*disable_peer_verification);
-  }
-}
-
-void setupClientFollowRedirects(extensions::curl::HTTPClient& client, const core::ProcessContext& context) {
-  if (auto follow_redirects = context.getProperty<bool>(InvokeHTTP::FollowRedirects))
-    client.setFollowRedirects(*follow_redirects);
-}
-
-void setupClientContentType(extensions::curl::HTTPClient& client, const core::ProcessContext& context, bool send_body) {
-  if (auto content_type = context.getProperty(InvokeHTTP::ContentType)) {
-    if (send_body)
-      client.setContentType(*content_type);
-  }
+  if (read_timeout)
+    client.setReadTimeout(*read_timeout);
 }
 
 void setupClientTransferEncoding(extensions::curl::HTTPClient& client, bool use_chunked_encoding) {
@@ -96,80 +64,92 @@ void setupClientTransferEncoding(extensions::curl::HTTPClient& client, bool use_
 }  // namespace
 
 void InvokeHTTP::setupMembersFromProperties(const core::ProcessContext& context) {
+  if (!context.getProperty(URL, url_))
+    throw Exception(PROCESS_SCHEDULE_EXCEPTION, "URL property missing or invalid");
+
+  method_ = utils::parseEnumProperty<utils::HttpRequestMethod>(context, Method);
+
   context.getProperty(SendMessageBody, send_message_body_);
 
   attributes_to_send_ = context.getProperty(AttributesToSend)
                         | utils::filter([](const std::string& s) { return !s.empty(); })  // avoid compiling an empty string to regex
-                        | utils::map([](const std::string& regex_str) { return utils::Regex{regex_str}; })
-                        | utils::orElse([this] { logger_->log_debug("%s is missing, so the default value will be used", std::string{AttributesToSend.name}); });
+                        | utils::transform([](const std::string& regex_str) { return utils::Regex{regex_str}; })
+                        | utils::orElse([this] { logger_->log_debug("{} is missing, so the default value will be used", AttributesToSend.name); });
 
-
-  always_output_response_ = (context.getProperty(AlwaysOutputResponse) | utils::flatMap(&utils::StringUtils::toBool)).value_or(false);
-  penalize_no_retry_ = (context.getProperty(PenalizeOnNoRetry) | utils::flatMap(&utils::StringUtils::toBool)).value_or(false);
+  always_output_response_ = (context.getProperty(AlwaysOutputResponse) | utils::andThen(&utils::string::toBool)).value_or(false);
+  penalize_no_retry_ = (context.getProperty(PenalizeOnNoRetry) | utils::andThen(&utils::string::toBool)).value_or(false);
 
   invalid_http_header_field_handling_strategy_ = utils::parseEnumProperty<invoke_http::InvalidHTTPHeaderFieldHandlingOption>(context, InvalidHTTPHeaderFieldHandlingStrategy);
 
   put_response_body_in_attribute_ = context.getProperty(PutResponseBodyInAttribute);
   if (put_response_body_in_attribute_ && put_response_body_in_attribute_->empty()) {
-    logger_->log_warn("%s is set to an empty string", std::string{PutResponseBodyInAttribute.name});
+    logger_->log_warn("{} is set to an empty string", PutResponseBodyInAttribute.name);
     put_response_body_in_attribute_.reset();
   }
 
-  use_chunked_encoding_ = (context.getProperty(UseChunkedEncoding) | utils::flatMap(&utils::StringUtils::toBool)).value_or(false);
+  use_chunked_encoding_ = (context.getProperty(UseChunkedEncoding) | utils::andThen(&utils::string::toBool)).value_or(false);
   send_date_header_ = context.getProperty<bool>(DateHeader).value_or(true);
-}
 
-std::unique_ptr<minifi::extensions::curl::HTTPClient> InvokeHTTP::createHTTPClientFromPropertiesAndMembers(const core::ProcessContext& context) const {
-  std::string method;
-  if (!context.getProperty(Method, method))
-    throw Exception(PROCESS_SCHEDULE_EXCEPTION, "Method property missing or invalid");
+  context.getProperty(UploadSpeedLimit, maximum_upload_speed_);
+  context.getProperty(DownloadSpeedLimit, maximum_download_speed_);
 
-  std::string url;
-  if (!context.getProperty(URL, url))
-    throw Exception(PROCESS_SCHEDULE_EXCEPTION, "URL property missing or invalid");
+  if (auto connection_timeout = context.getProperty<core::TimePeriodValue>(InvokeHTTP::ConnectTimeout))
+    connect_timeout_ = connection_timeout->getMilliseconds();
+
+  if (auto read_timeout = context.getProperty<core::TimePeriodValue>(InvokeHTTP::ReadTimeout))
+    read_timeout_ = read_timeout->getMilliseconds();
+
+  context.getProperty(InvokeHTTP::ProxyHost, proxy_.host);
+  std::string port_str;
+  if (context.getProperty(InvokeHTTP::ProxyPort, port_str) && !port_str.empty()) {
+    core::Property::StringToInt(port_str, proxy_.port);
+  }
+  context.getProperty(InvokeHTTP::ProxyUsername, proxy_.username);
+  context.getProperty(InvokeHTTP::ProxyPassword, proxy_.password);
+
+  follow_redirects_ = context.getProperty<bool>(InvokeHTTP::FollowRedirects).value_or(false);
+  content_type_ = context.getProperty(InvokeHTTP::ContentType);
 
-  std::shared_ptr<minifi::controllers::SSLContextService> ssl_context_service;
   if (auto ssl_context_name = context.getProperty(SSLContext)) {
     if (auto service = context.getControllerService(*ssl_context_name)) {
-      ssl_context_service = std::dynamic_pointer_cast<minifi::controllers::SSLContextService>(service);
-      if (!ssl_context_service)
-        logger_->log_error("Controller service '%s' is not an SSLContextService", *ssl_context_name);
+      ssl_context_service_ = std::dynamic_pointer_cast<minifi::controllers::SSLContextService>(service);
+      if (!ssl_context_service_)
+        logger_->log_error("Controller service '{}' is not an SSLContextService", *ssl_context_name);
     } else {
-      logger_->log_error("Couldn't find controller service with name '%s'", *ssl_context_name);
+      logger_->log_error("Couldn't find controller service with name '{}'", *ssl_context_name);
     }
   }
+}
 
+std::unique_ptr<minifi::extensions::curl::HTTPClient> InvokeHTTP::createHTTPClientFromMembers() const {
   auto client = std::make_unique<minifi::extensions::curl::HTTPClient>();
-  client->initialize(std::move(method), std::move(url), std::move(ssl_context_service));
-  setupClientTimeouts(*client, context);
-  setupClientProxy(*client, context);
-  setupClientFollowRedirects(*client, context);
-  setupClientPeerVerification(*client, context);
-  setupClientContentType(*client, context, send_message_body_);
+  client->initialize(method_, url_, ssl_context_service_);
+  setupClientTimeouts(*client, connect_timeout_, read_timeout_);
+  client->setHTTPProxy(proxy_);
+  client->setFollowRedirects(follow_redirects_);
+  client->setPeerVerification(true);
+  if (send_message_body_ && content_type_)
+    client->setContentType(*content_type_);
   setupClientTransferEncoding(*client, use_chunked_encoding_);
+  client->setMaximumUploadSpeed(maximum_upload_speed_.getValue());
+  client->setMaximumDownloadSpeed(maximum_download_speed_.getValue());
 
   return client;
 }
 
 
-void InvokeHTTP::onSchedule(const std::shared_ptr<core::ProcessContext>& context, const std::shared_ptr<core::ProcessSessionFactory>& /*sessionFactory*/) {
-  gsl_Expects(context);
+void InvokeHTTP::onSchedule(core::ProcessContext& context, core::ProcessSessionFactory&) {
+  setupMembersFromProperties(context);
 
-  setupMembersFromProperties(*context);
-  std::weak_ptr<core::ProcessContext> weak_context = context;
-  auto create_client = [this, weak_context]() -> std::unique_ptr<minifi::extensions::curl::HTTPClient> {
-    if (auto context = weak_context.lock())
-      return createHTTPClientFromPropertiesAndMembers(*context);
-    else
-      return nullptr;
+  auto create_client = [this]() -> std::unique_ptr<minifi::extensions::curl::HTTPClient> {
+    return createHTTPClientFromMembers();
   };
 
   client_queue_ = utils::ResourceQueue<extensions::curl::HTTPClient>::create(create_client, getMaxConcurrentTasks(), std::nullopt, logger_);
 }
 
-bool InvokeHTTP::shouldEmitFlowFile(minifi::extensions::curl::HTTPClient& client) {
-  auto method = client.getRequestMethod();
-  return ("POST" == method || "PUT" == method || "PATCH" == method);
+bool InvokeHTTP::shouldEmitFlowFile() const {
+  return (utils::HttpRequestMethod::POST == method_ || utils::HttpRequestMethod::PUT == method_ || utils::HttpRequestMethod::PATCH == method_);
 }
 
 /**
@@ -205,24 +185,17 @@ bool InvokeHTTP::appendHeaders(const core::FlowFile& flow_file, /*std::invocable
   return true;
 }
 
-void InvokeHTTP::onTrigger(const std::shared_ptr<core::ProcessContext>& context, const std::shared_ptr<core::ProcessSession>& session) {
-  gsl_Expects(session && context && client_queue_);
+void InvokeHTTP::onTrigger(core::ProcessContext& context, core::ProcessSession& session) {
+  gsl_Expects(client_queue_);
 
-  auto client = client_queue_->getResource();
-
-  onTriggerWithClient(context, session, *client);
-}
-
-void InvokeHTTP::onTriggerWithClient(const std::shared_ptr<core::ProcessContext>& context, const std::shared_ptr<core::ProcessSession>& session,
-                                     minifi::extensions::curl::HTTPClient& client) {
-  auto flow_file = session->get();
+  auto flow_file = session.get();
 
   if (flow_file == nullptr) {
-    if (!shouldEmitFlowFile(client)) {
-      logger_->log_debug("InvokeHTTP -- create flow file with  %s", client.getRequestMethod());
-      flow_file = session->create();
+    if (!shouldEmitFlowFile()) {
+      logger_->log_debug("InvokeHTTP -- create flow file with  {}", magic_enum::enum_name(method_));
+      flow_file = session.create();
     } else {
-      logger_->log_debug("Exiting because method is %s and there is no flowfile available to execute it, yielding", client.getRequestMethod());
+      logger_->log_debug("Exiting because method is {} and there is no flowfile available to execute it, yielding", magic_enum::enum_name(method_));
       yield();
       return;
     }
@@ -230,7 +203,14 @@ void InvokeHTTP::onTriggerWithClient(const std::shared_ptr<core::ProcessContext>
     logger_->log_debug("InvokeHTTP -- Received flowfile");
   }
 
-  logger_->log_debug("onTrigger InvokeHTTP with %s to %s", client.getRequestMethod(), client.getURL());
+  auto client = client_queue_->getResource();
+
+  onTriggerWithClient(context, session, flow_file, *client);
+}
+
+void InvokeHTTP::onTriggerWithClient(core::ProcessContext& context, core::ProcessSession& session,
+    const std::shared_ptr<core::FlowFile>& flow_file, minifi::extensions::curl::HTTPClient& client) {
+  logger_->log_debug("onTrigger InvokeHTTP with {} to {}", magic_enum::enum_name(method_), client.getURL());
 
   const auto remove_callback_from_client_at_exit = gsl::finally([&client] {
     client.setUploadCallback({});
@@ -238,9 +218,9 @@ void InvokeHTTP::onTriggerWithClient(const std::shared_ptr<core::ProcessContext>
 
   std::string transaction_id = utils::IdGenerator::getIdGenerator()->generate().to_string();
 
-  if (shouldEmitFlowFile(client)) {
+  if (shouldEmitFlowFile()) {
     logger_->log_trace("InvokeHTTP -- reading flowfile");
-    const auto flow_file_reader_stream = session->getFlowFileContentStream(flow_file);
+    const auto flow_file_reader_stream = session.getFlowFileContentStream(*flow_file);
     if (flow_file_reader_stream) {
       std::unique_ptr<utils::HTTPUploadCallback> callback_obj;
       if (send_message_body_) {
@@ -249,7 +229,7 @@ void InvokeHTTP::onTriggerWithClient(const std::shared_ptr<core::ProcessContext>
         callback_obj = std::make_unique<utils::HTTPUploadByteArrayInputCallback>();
       }
       client.setUploadCallback(std::move(callback_obj));
-      logger_->log_trace("InvokeHTTP -- Setting callback, size is %d", flow_file->getSize());
+      logger_->log_trace("InvokeHTTP -- Setting callback, size is {}", flow_file->getSize());
 
       if (!send_message_body_) {
         client.setRequestHeader("Content-Length", "0");
@@ -273,7 +253,7 @@ void InvokeHTTP::onTriggerWithClient(const std::shared_ptr<core::ProcessContext>
 
   const auto append_header = [&](const std::string& key, const std::string& value) { client.setRequestHeader(key, value); };
   if (!appendHeaders(*flow_file, append_header)) {
-    session->transfer(flow_file, RelFailure);
+    session.transfer(flow_file, RelFailure);
     return;
   }
 
@@ -293,16 +273,12 @@ void InvokeHTTP::onTriggerWithClient(const std::shared_ptr<core::ProcessContext>
 
     bool is_success = ((http_code / 100) == 2);
 
-    logger_->log_debug("isSuccess: %d, response code %" PRId64, is_success, http_code);
+    logger_->log_debug("isSuccess: {}, response code {}", is_success, http_code);
     std::shared_ptr<core::FlowFile> response_flow = nullptr;
 
     if (is_success) {
       if (!put_response_body_in_attribute_) {
-        if (flow_file != nullptr) {
-          response_flow = session->create(flow_file);
-        } else {
-          response_flow = session->create();
-        }
+        response_flow = session.create(flow_file.get());
 
         // if content type isn't returned we should return application/octet-stream
         // as per RFC 2046 -- 4.5.1
@@ -313,7 +289,7 @@ void InvokeHTTP::onTriggerWithClient(const std::shared_ptr<core::ProcessContext>
         response_flow->addAttribute(TRANSACTION_ID, transaction_id);
         io::BufferStream stream(gsl::make_span(response_body).as_span<const std::byte>());
         // need an import from the data stream.
-        session->importFrom(stream, response_flow);
+        session.importFrom(stream, response_flow);
       } else {
         if (!response_body.empty()) {
           std::string body_attribute_str{response_body.data(), response_body.size()};
@@ -323,23 +299,23 @@ void InvokeHTTP::onTriggerWithClient(const std::shared_ptr<core::ProcessContext>
     }
     route(flow_file, response_flow, session, context, is_success, http_code);
   } else {
-    session->penalize(flow_file);
-    session->transfer(flow_file, RelFailure);
+    session.penalize(flow_file);
+    session.transfer(flow_file, RelFailure);
   }
 }
 
-void InvokeHTTP::route(const std::shared_ptr<core::FlowFile>& request, const std::shared_ptr<core::FlowFile>& response, const std::shared_ptr<core::ProcessSession>& session,
-                       const std::shared_ptr<core::ProcessContext>& context, bool is_success, int64_t status_code) {
+void InvokeHTTP::route(const std::shared_ptr<core::FlowFile>& request, const std::shared_ptr<core::FlowFile>& response, core::ProcessSession& session,
+                       core::ProcessContext& context, bool is_success, int64_t status_code) {
   // check if we should yield the processor
   if (!is_success && request == nullptr) {
-    context->yield();
+    context.yield();
   }
 
   // If the property to output the response flowfile regardless of status code is set then transfer it
   bool response_sent = false;
   if (always_output_response_ && response != nullptr) {
     logger_->log_debug("Outputting success and response");
-    session->transfer(response, RelResponse);
+    session.transfer(response, RelResponse);
     response_sent = true;
   }
 
@@ -348,25 +324,25 @@ void InvokeHTTP::route(const std::shared_ptr<core::FlowFile>& request, const std
   if (is_success) {
     // we have two flowfiles to transfer
     if (request != nullptr) {
-      session->transfer(request, Success);
+      session.transfer(request, Success);
     }
     if (response != nullptr && !response_sent) {
       logger_->log_debug("Outputting success and response");
-      session->transfer(response, RelResponse);
+      session.transfer(response, RelResponse);
     }
     // 5xx -> RETRY
   } else if (status_code / 100 == 5) {
     if (request != nullptr) {
-      session->penalize(request);
-      session->transfer(request, RelRetry);
+      session.penalize(request);
+      session.transfer(request, RelRetry);
     }
     // 1xx, 3xx, 4xx -> NO RETRY
   } else {
     if (request != nullptr) {
       if (penalize_no_retry_) {
-        session->penalize(request);
+        session.penalize(request);
       }
-      session->transfer(request, RelNoRetry);
+      session.transfer(request, RelNoRetry);
     }
   }
 }
