@@ -58,8 +58,8 @@ class InvokeHTTP : public core::Processor {
   EXTENSIONAPI static constexpr std::string_view REQUEST_URL = "invokehttp.request.url";
   EXTENSIONAPI static constexpr std::string_view TRANSACTION_ID = "invokehttp.tx.id";
 
-  explicit InvokeHTTP(std::string name, const utils::Identifier& uuid = {})
-      : Processor(std::move(name), uuid) {
+  explicit InvokeHTTP(std::string_view name, const utils::Identifier& uuid = {})
+      : Processor(name, uuid) {
     setTriggerWhenEmpty(true);
   }
 
@@ -67,10 +67,10 @@ class InvokeHTTP : public core::Processor {
                                                           "The destination URL and HTTP Method are configurable. FlowFile attributes are converted to HTTP headers and the "
                                                           "FlowFile contents are included as the body of the request (if the HTTP Method is PUT, POST or PATCH).";
 
-  EXTENSIONAPI static constexpr auto Method = core::PropertyDefinitionBuilder<>::createProperty("HTTP Method")
-      .withDescription("HTTP request method (GET, POST, PUT, PATCH, DELETE, HEAD, OPTIONS). "
-          "Arbitrary methods are also supported. Methods other than POST, PUT and PATCH will be sent without a message body.")
-      .withDefaultValue("GET")
+  EXTENSIONAPI static constexpr auto Method = core::PropertyDefinitionBuilder<magic_enum::enum_count<utils::HttpRequestMethod>()>::createProperty("HTTP Method")
+      .withDescription("HTTP request method. Methods other than POST, PUT and PATCH will be sent without a message body.")
+      .withAllowedValues(magic_enum::enum_names<utils::HttpRequestMethod>())
+      .withDefaultValue(magic_enum::enum_name(utils::HttpRequestMethod::GET))
       .build();
   EXTENSIONAPI static constexpr auto URL = core::PropertyDefinitionBuilder<>::createProperty("Remote URL")
       .withDescription("Remote URL which will be connected to, including scheme, host, port, path.")
@@ -123,6 +123,7 @@ class InvokeHTTP : public core::Processor {
   EXTENSIONAPI static constexpr auto ProxyPassword = core::PropertyDefinitionBuilder<>::createProperty("invokehttp-proxy-password", "Proxy Password")
       .withDescription("Password to set when authenticating against proxy")
       .isRequired(false)
+      .isSensitive(true)
       .build();
   EXTENSIONAPI static constexpr auto ContentType = core::PropertyDefinitionBuilder<>::createProperty("Content-type")
       .withDescription("The Content-Type to specify for when content is being transmitted through a PUT, "
@@ -149,7 +150,7 @@ class InvokeHTTP : public core::Processor {
       .withDefaultValue("false")
       .build();
   EXTENSIONAPI static constexpr auto DisablePeerVerification = core::PropertyDefinitionBuilder<>::createProperty("Disable Peer Verification")
-      .withDescription("Disables peer verification for the SSL session")
+      .withDescription("DEPRECATED. The value is ignored, peer and host verification are always performed when using SSL/TLS.")
       .withPropertyType(core::StandardPropertyTypes::BOOLEAN_TYPE)
       .withDefaultValue("false")
       .build();
@@ -177,8 +178,16 @@ class InvokeHTTP : public core::Processor {
       .withDefaultValue(magic_enum::enum_name(invoke_http::InvalidHTTPHeaderFieldHandlingOption::transform))
       .withAllowedValues(magic_enum::enum_names<invoke_http::InvalidHTTPHeaderFieldHandlingOption>())
       .build();
+  EXTENSIONAPI static constexpr auto UploadSpeedLimit = core::PropertyDefinitionBuilder<>::createProperty("Upload Speed Limit")
+      .withDescription("Maximum upload speed, e.g. '500 KB/s'. Leave this empty if you want no limit.")
+      .withPropertyType(core::StandardPropertyTypes::DATA_TRANSFER_SPEED_TYPE)
+      .build();
+  EXTENSIONAPI static constexpr auto DownloadSpeedLimit = core::PropertyDefinitionBuilder<>::createProperty("Download Speed Limit")
+      .withDescription("Maximum download speed,e.g. '500 KB/s'. Leave this empty if you want no limit.")
+      .withPropertyType(core::StandardPropertyTypes::DATA_TRANSFER_SPEED_TYPE)
+      .build();
 
-  EXTENSIONAPI static constexpr auto Properties = std::array<core::PropertyReference, 21>{
+  EXTENSIONAPI static constexpr auto Properties = std::array<core::PropertyReference, 23>{
         Method,
         URL,
         ConnectTimeout,
@@ -199,7 +208,9 @@ class InvokeHTTP : public core::Processor {
         PutResponseBodyInAttribute,
         AlwaysOutputResponse,
         PenalizeOnNoRetry,
-        InvalidHTTPHeaderFieldHandlingStrategy
+        InvalidHTTPHeaderFieldHandlingStrategy,
+        UploadSpeedLimit,
+        DownloadSpeedLimit
   };
 
 
@@ -251,31 +262,45 @@ class InvokeHTTP : public core::Processor {
 
   EXTENSIONAPI static std::string DefaultContentType;
 
-  void onTrigger(const std::shared_ptr<core::ProcessContext>& context, const std::shared_ptr<core::ProcessSession>& session) override;
+  void onTrigger(core::ProcessContext& context, core::ProcessSession& session) override;
   void initialize() override;
-  void onSchedule(const std::shared_ptr<core::ProcessContext>& context, const std::shared_ptr<core::ProcessSessionFactory>& sessionFactory) override;
+  void onSchedule(core::ProcessContext& context, core::ProcessSessionFactory& session_factory) override;
 
  private:
-  void route(const std::shared_ptr<core::FlowFile>& request, const std::shared_ptr<core::FlowFile>& response, const std::shared_ptr<core::ProcessSession>& session,
-             const std::shared_ptr<core::ProcessContext>& context, bool is_success, int64_t status_code);
-  static bool shouldEmitFlowFile(minifi::extensions::curl::HTTPClient& client);
-  void onTriggerWithClient(const std::shared_ptr<core::ProcessContext>& context, const std::shared_ptr<core::ProcessSession>& session, minifi::extensions::curl::HTTPClient& client);
+  void route(const std::shared_ptr<core::FlowFile>& request, const std::shared_ptr<core::FlowFile>& response, core::ProcessSession& session,
+             core::ProcessContext& context, bool is_success, int64_t status_code);
+  [[nodiscard]] bool shouldEmitFlowFile() const;
+  void onTriggerWithClient(core::ProcessContext& context, core::ProcessSession& session,
+                           const std::shared_ptr<core::FlowFile>& flow_file, minifi::extensions::curl::HTTPClient& client);
   [[nodiscard]] bool appendHeaders(const core::FlowFile& flow_file, /*std::invocable<std::string, std::string>*/ auto append_header);
 
 
   void setupMembersFromProperties(const core::ProcessContext& context);
-  std::unique_ptr<minifi::extensions::curl::HTTPClient> createHTTPClientFromPropertiesAndMembers(const core::ProcessContext& context) const;
+  std::unique_ptr<minifi::extensions::curl::HTTPClient> createHTTPClientFromMembers() const;
 
+  utils::HttpRequestMethod method_{};
   std::optional<utils::Regex> attributes_to_send_;
-
   std::optional<std::string> put_response_body_in_attribute_;
   bool always_output_response_{false};
   bool use_chunked_encoding_{false};
   bool penalize_no_retry_{false};
   bool send_message_body_{true};
   bool send_date_header_{true};
+  core::DataTransferSpeedValue maximum_upload_speed_{0};
+  core::DataTransferSpeedValue maximum_download_speed_{0};
 
-  invoke_http::InvalidHTTPHeaderFieldHandlingOption invalid_http_header_field_handling_strategy_;
+  std::string url_;
+  std::shared_ptr<minifi::controllers::SSLContextService> ssl_context_service_;
+
+  std::chrono::milliseconds connect_timeout_{std::chrono::seconds(30)};
+  std::chrono::milliseconds read_timeout_{std::chrono::seconds(30)};
+
+  utils::HTTPProxy proxy_{};
+  bool follow_redirects_ = false;
+  std::optional<std::string> content_type_;
+
+
+  invoke_http::InvalidHTTPHeaderFieldHandlingOption invalid_http_header_field_handling_strategy_{};
 
   std::shared_ptr<core::logging::Logger> logger_{core::logging::LoggerFactory<InvokeHTTP>::getLogger(uuid_)};
   std::shared_ptr<utils::ResourceQueue<extensions::curl::HTTPClient>> client_queue_;
