@@ -32,8 +32,8 @@ using namespace std::literals::chrono_literals;
 
 namespace org::apache::nifi::minifi::c2 {
 
-RESTSender::RESTSender(std::string name, const utils::Identifier &uuid)
-    : C2Protocol(std::move(name), uuid) {
+RESTSender::RESTSender(std::string_view name, const utils::Identifier &uuid)
+    : C2Protocol(name, uuid) {
 }
 
 void RESTSender::initialize(core::controller::ControllerServiceProvider* controller, const std::shared_ptr<Configure> &configure) {
@@ -52,25 +52,25 @@ void RESTSender::initialize(core::controller::ControllerServiceProvider* control
     }
     if (nullptr == ssl_context_service_) {
       std::string ssl_context_str;
-      if (configure->get(Configure::nifi_remote_input_secure, ssl_context_str) && org::apache::nifi::minifi::utils::StringUtils::toBool(ssl_context_str).value_or(false)) {
+      if (configure->get(Configure::nifi_remote_input_secure, ssl_context_str) && org::apache::nifi::minifi::utils::string::toBool(ssl_context_str).value_or(false)) {
         ssl_context_service_ = std::make_shared<minifi::controllers::SSLContextService>("RESTSenderSSL", configure);
         ssl_context_service_->onEnable();
       }
     }
     if (auto req_encoding_str = configure->get(Configuration::nifi_c2_rest_request_encoding)) {
       if (auto req_encoding = magic_enum::enum_cast<RequestEncoding>(*req_encoding_str, magic_enum::case_insensitive)) {
-        logger_->log_debug("Using request encoding '%s'", std::string{magic_enum::enum_name(*req_encoding)});
+        logger_->log_debug("Using request encoding '{}'", magic_enum::enum_name(*req_encoding));
         req_encoding_ = *req_encoding;
       } else {
-        logger_->log_error("Invalid request encoding '%s'", req_encoding_str.value());
+        logger_->log_error("Invalid request encoding '{}'", req_encoding_str.value());
         req_encoding_ = RequestEncoding::none;
       }
     } else {
-      logger_->log_debug("Request encoding is not specified, using default '%s'", std::string{magic_enum::enum_name(RequestEncoding::none)});
+      logger_->log_debug("Request encoding is not specified, using default '{}'", magic_enum::enum_name(RequestEncoding::none));
       req_encoding_ = RequestEncoding::none;
     }
   }
-  logger_->log_debug("Submitting to %s", rest_uri_);
+  logger_->log_debug("Submitting to {}", rest_uri_);
 }
 
 C2Payload RESTSender::consumePayload(const std::string &url, const C2Payload &payload, Direction direction, bool /*async*/) {
@@ -93,7 +93,7 @@ C2Payload RESTSender::consumePayload(const C2Payload &payload, Direction directi
 void RESTSender::update(const std::shared_ptr<Configure> &) {
 }
 
-void RESTSender::setSecurityContext(extensions::curl::HTTPClient &client, const std::string &type, const std::string &url) {
+void RESTSender::setSecurityContext(extensions::curl::HTTPClient &client, utils::HttpRequestMethod type, const std::string &url) {
   // only use the SSL Context if we have a secure URL.
   auto generatedService = std::make_shared<minifi::controllers::SSLContextService>("Service", configuration_);
   generatedService->onEnable();
@@ -111,7 +111,7 @@ C2Payload RESTSender::sendPayload(const std::string& url, const Direction direct
   client.setKeepAliveProbe(extensions::curl::KeepAliveProbeData{2s, 2s});
   client.setConnectionTimeout(2s);
 
-  auto setUpHttpRequest = [&](const std::string& http_method) {
+  auto setUpHttpRequest = [&](utils::HttpRequestMethod http_method) {
     client.set_request_method(http_method);
     if (url.find("https://") == 0) {
       if (!ssl_context_service_) {
@@ -122,7 +122,7 @@ C2Payload RESTSender::sendPayload(const std::string& url, const Direction direct
     }
   };
   if (direction == Direction::TRANSMIT) {
-    setUpHttpRequest("POST");
+    setUpHttpRequest(utils::HttpRequestMethod::POST);
     if (payload.getOperation() == Operation::transfer) {
       // treat nested payloads as files
       for (const auto& file : payload.getNestedPayloads()) {
@@ -163,14 +163,14 @@ C2Payload RESTSender::sendPayload(const std::string& url, const Direction direct
   } else {
     // we do not need to set the upload callback
     // since we are not uploading anything on a get
-    setUpHttpRequest("GET");
+    setUpHttpRequest(utils::HttpRequestMethod::GET);
   }
 
   if (payload.getOperation() == Operation::transfer) {
     auto read = std::make_unique<utils::HTTPReadCallback>(std::numeric_limits<size_t>::max());
     client.setReadCallback(std::move(read));
     if (accepted_formats && !accepted_formats->empty()) {
-      client.setRequestHeader("Accept", utils::StringUtils::join(", ", accepted_formats.value()));
+      client.setRequestHeader("Accept", utils::string::join(", ", accepted_formats.value()));
     }
   } else {
     // Due to a bug in MiNiFi C2 the Accept header is not handled properly thus we need to exclude it to be compatible
@@ -183,12 +183,12 @@ C2Payload RESTSender::sendPayload(const std::string& url, const Direction direct
   const bool clientError = 400 <= respCode && respCode < 500;
   const bool serverError = 500 <= respCode && respCode < 600;
   if (clientError || serverError) {
-    logger_->log_error("Error response code '" "%" PRId64 "' from '%s'", respCode, url);
+    logger_->log_error("Error response code '{}' from '{}'", respCode, url);
   } else {
-    logger_->log_debug("Response code '" "%" PRId64 "' from '%s'", respCode, url);
+    logger_->log_debug("Response code '{}' from '{}'", respCode, url);
   }
   const auto response_body_bytes = gsl::make_span(client.getResponseBody()).as_span<const std::byte>();
-  logger_->log_trace("Received response: \"%s\"", [&] {return utils::StringUtils::escapeUnprintableBytes(response_body_bytes);});
+  logger_->log_trace("Received response: \"{}\"", [&] { return utils::string::escapeUnprintableBytes(response_body_bytes); });
   if (isOkay && !clientError && !serverError) {
     if (accepted_formats) {
       C2Payload response_payload(payload.getOperation(), state::UpdateState::READ_COMPLETE, true);
