@@ -50,7 +50,7 @@ void ExecuteJavaProcessor::initialize() {
   setSupportedRelationships(Relationships);
 }
 
-void ExecuteJavaProcessor::onSchedule(const std::shared_ptr<core::ProcessContext>& context, const std::shared_ptr<core::ProcessSessionFactory>& /*sessionFactory*/) {
+void ExecuteJavaProcessor::onScheduleSharedPtr(const std::shared_ptr<core::ProcessContext>& context, const std::shared_ptr<core::ProcessSessionFactory>& /*sessionFactory*/) {
   gsl_Expects(context);
 
   std::string controller_service_name;
@@ -198,18 +198,14 @@ void ExecuteJavaProcessor::onTrigger(const std::shared_ptr<core::ProcessContext>
   } catch (const JavaException &je) {
     // clear the java exception so we don't continually wrap it
     env->ExceptionClear();
-    logger_->log_error(" Java Exception occurred during onTrigger, reason: %s", je.what());
+    logger_->log_error(" Java Exception occurred during onTrigger, reason: {}", je.what());
   } catch (const std::exception &e) {
     // clear the java exception so we don't continually wrap it
     env->ExceptionClear();
-    logger_->log_error(" Exception occurred during onTrigger, reason: %s", e.what());
+    logger_->log_error(" Exception occurred during onTrigger, reason: {}", e.what());
   }
 }
 
-void ExecuteJavaProcessor::onTrigger(const std::shared_ptr<core::ProcessContext>& /*context*/, const std::shared_ptr<core::ProcessSession>& /*session*/) {
-  // do nothing.
-}
-
 REGISTER_RESOURCE_AS(ExecuteJavaProcessor, Processor, ("ExecuteJavaClass"));
 
 }  // namespace org::apache::nifi::minifi::jni::processors
