@@ -30,27 +30,25 @@ void CollectKubernetesPodMetrics::initialize() {
   setSupportedRelationships(Relationships);
 }
 
-void CollectKubernetesPodMetrics::onSchedule(const std::shared_ptr<core::ProcessContext>& context, const std::shared_ptr<core::ProcessSessionFactory>&) {
-  gsl_Expects(context);
-
-  const auto controller_service_name = context->getProperty(KubernetesControllerService);
+void CollectKubernetesPodMetrics::onSchedule(core::ProcessContext& context, core::ProcessSessionFactory&) {
+  const auto controller_service_name = context.getProperty(KubernetesControllerService);
   if (!controller_service_name || controller_service_name->empty()) {
-    throw minifi::Exception{ExceptionType::PROCESS_SCHEDULE_EXCEPTION, utils::StringUtils::join_pack("Missing '", KubernetesControllerService.name, "' property")};
+    throw minifi::Exception{ExceptionType::PROCESS_SCHEDULE_EXCEPTION, utils::string::join_pack("Missing '", KubernetesControllerService.name, "' property")};
   }
 
-  std::shared_ptr<core::controller::ControllerService> controller_service = context->getControllerService(*controller_service_name);
+  std::shared_ptr<core::controller::ControllerService> controller_service = context.getControllerService(*controller_service_name);
   if (!controller_service) {
-    throw minifi::Exception{ExceptionType::PROCESS_SCHEDULE_EXCEPTION, utils::StringUtils::join_pack("Controller service '", *controller_service_name, "' not found")};
+    throw minifi::Exception{ExceptionType::PROCESS_SCHEDULE_EXCEPTION, utils::string::join_pack("Controller service '", *controller_service_name, "' not found")};
   }
 
   kubernetes_controller_service_ = std::dynamic_pointer_cast<minifi::controllers::KubernetesControllerService>(controller_service);
   if (!kubernetes_controller_service_) {
-    throw minifi::Exception{ExceptionType::PROCESS_SCHEDULE_EXCEPTION, utils::StringUtils::join_pack("Controller service '", *controller_service_name, "' is not a KubernetesControllerService")};
+    throw minifi::Exception{ExceptionType::PROCESS_SCHEDULE_EXCEPTION, utils::string::join_pack("Controller service '", *controller_service_name, "' is not a KubernetesControllerService")};
   }
 }
 
-void CollectKubernetesPodMetrics::onTrigger(const std::shared_ptr<core::ProcessContext>& context, const std::shared_ptr<core::ProcessSession>& session) {
-  gsl_Expects(context && session && kubernetes_controller_service_);
+void CollectKubernetesPodMetrics::onTrigger(core::ProcessContext&, core::ProcessSession& session) {
+  gsl_Expects(kubernetes_controller_service_);
 
   const kubernetes::ApiClient* api_client = kubernetes_controller_service_->apiClient();
   if (!api_client) {
@@ -59,7 +57,7 @@ void CollectKubernetesPodMetrics::onTrigger(const std::shared_ptr<core::ProcessC
 
   const auto metrics = kubernetes::metrics::podMetricsList(*api_client);
   if (!metrics) {
-    logger_->log_error("Could not get metrics from the Kubernetes API: %s", metrics.error());
+    logger_->log_error("Could not get metrics from the Kubernetes API: {}", metrics.error());
     return;
   }
 
@@ -67,15 +65,15 @@ void CollectKubernetesPodMetrics::onTrigger(const std::shared_ptr<core::ProcessC
     return kubernetes_controller_service_->matchesRegexFilters(container_info);
   });
   if (!metrics_filtered) {
-    logger_->log_error("Error parsing or filtering the metrics received from the Kubernetes API: %s", metrics_filtered.error());
+    logger_->log_error("Error parsing or filtering the metrics received from the Kubernetes API: {}", metrics_filtered.error());
     return;
   }
 
-  logger_->log_debug("Metrics received from the Kubernetes API: %s", metrics_filtered.value());
+  logger_->log_debug("Metrics received from the Kubernetes API: {}", metrics_filtered.value());
 
-  const auto flow_file = session->create();
-  session->writeBuffer(flow_file, metrics_filtered.value());
-  session->transfer(flow_file, Success);
+  const auto flow_file = session.create();
+  session.writeBuffer(flow_file, metrics_filtered.value());
+  session.transfer(flow_file, Success);
 }
 
 REGISTER_RESOURCE(CollectKubernetesPodMetrics, Processor);
