@@ -52,10 +52,10 @@ class Bin {
     queued_data_size_ = 0;
     creation_dated_ = std::chrono::system_clock::now();
     uuid_ = utils::IdGenerator::getIdGenerator()->generate();
-    logger_->log_debug("Bin %s for group %s created", getUUIDStr(), groupId_);
+    logger_->log_debug("Bin {} for group {} created", getUUIDStr(), groupId_);
   }
   virtual ~Bin() {
-    logger_->log_debug("Bin %s for group %s destroyed", getUUIDStr(), groupId_);
+    logger_->log_debug("Bin {} for group {} destroyed", getUUIDStr(), groupId_);
   }
   [[nodiscard]] bool isFull() const {
     return queued_data_size_ >= maxSize_ || queue_.size() >= maxEntries_;
@@ -91,7 +91,7 @@ class Bin {
 
     queue_.push_back(flow);
     queued_data_size_ += flow->getSize();
-    logger_->log_debug("Bin %s for group %s offer size %zu byte %" PRIu64 " min_entry %zu max_entry %zu", getUUIDStr(), groupId_, queue_.size(), queued_data_size_, minEntries_, maxEntries_);
+    logger_->log_debug("Bin {} for group {} offer size {} byte {} min_entry {} max_entry {}", getUUIDStr(), groupId_, queue_.size(), queued_data_size_, minEntries_, maxEntries_);
 
     return true;
   }
@@ -256,10 +256,8 @@ class BinFiles : public core::Processor {
   EXTENSIONAPI static const char *SEGMENT_ORIGINAL_FILENAME;
   EXTENSIONAPI static const char *TAR_PERMISSIONS_ATTRIBUTE;
 
-  void onSchedule(core::ProcessContext *context, core::ProcessSessionFactory *sessionFactory) override;
-  void onTrigger(core::ProcessContext* /*context*/, core::ProcessSession* /*session*/) override {
-  }
-  void onTrigger(const std::shared_ptr<core::ProcessContext> &context, const std::shared_ptr<core::ProcessSession> &session) override;
+  void onSchedule(core::ProcessContext& context, core::ProcessSessionFactory& session_factory) override;
+  void onTrigger(core::ProcessContext& context, core::ProcessSession& session) override;
   void initialize() override;
 
   void restore(const std::shared_ptr<core::FlowFile>& flowFile) override;
@@ -281,7 +279,7 @@ class BinFiles : public core::Processor {
 
   // Sort flow files retrieved from the flow file repository after restart to their respective bins
   bool resurrectFlowFiles(core::ProcessSession &session);
-  void assumeOwnershipOfNextBatch(core::ProcessSession &session);
+  bool assumeOwnershipOfNextBatch(core::ProcessSession &session);
   std::deque<std::unique_ptr<Bin>> gatherReadyBins(core::ProcessContext &context);
   void processReadyBins(std::deque<std::unique_ptr<Bin>> ready_bins, core::ProcessSession &session);
 
@@ -295,4 +293,3 @@ class BinFiles : public core::Processor {
 };
 
 }  // namespace org::apache::nifi::minifi::processors
-
