@@ -38,8 +38,8 @@ using core::logging::Logger;
 
 class ManipulateArchive : public core::Processor {
  public:
-  explicit ManipulateArchive(std::string name, const utils::Identifier& uuid = {})
-      : core::Processor(std::move(name), uuid) {
+  explicit ManipulateArchive(std::string_view name, const utils::Identifier& uuid = {})
+      : core::Processor(name, uuid) {
   }
   ~ManipulateArchive() override = default;
 
@@ -86,8 +86,8 @@ class ManipulateArchive : public core::Processor {
   EXTENSIONAPI static char const* OPERATION_MOVE;
   EXTENSIONAPI static char const* OPERATION_TOUCH;
 
-  void onTrigger(core::ProcessContext *context, core::ProcessSession *session) override;
-  void onSchedule(core::ProcessContext *context, core::ProcessSessionFactory *sessionFactory) override;
+  void onTrigger(core::ProcessContext& context, core::ProcessSession& session) override;
+  void onSchedule(core::ProcessContext& context, core::ProcessSessionFactory& session_factory) override;
   void initialize() override;
 
  private:
