@@ -49,36 +49,36 @@ std::string MergeContent::readContent(const std::string& path) {
   return (contents);
 }
 
-void MergeContent::onSchedule(core::ProcessContext *context, core::ProcessSessionFactory *sessionFactory) {
-  BinFiles::onSchedule(context, sessionFactory);
+void MergeContent::onSchedule(core::ProcessContext& context, core::ProcessSessionFactory& session_factory) {
+  BinFiles::onSchedule(context, session_factory);
 
-  context->getProperty(MergeStrategy, mergeStrategy_);
-  context->getProperty(MergeFormat, mergeFormat_);
-  context->getProperty(CorrelationAttributeName, correlationAttributeName_);
-  context->getProperty(DelimiterStrategy, delimiterStrategy_);
-  context->getProperty(Header, header_);
-  context->getProperty(Footer, footer_);
-  context->getProperty(Demarcator, demarcator_);
-  context->getProperty(KeepPath, keepPath_);
-  context->getProperty(AttributeStrategy, attributeStrategy_);
+  context.getProperty(MergeStrategy, mergeStrategy_);
+  context.getProperty(MergeFormat, mergeFormat_);
+  context.getProperty(CorrelationAttributeName, correlationAttributeName_);
+  context.getProperty(DelimiterStrategy, delimiterStrategy_);
+  context.getProperty(Header, header_);
+  context.getProperty(Footer, footer_);
+  context.getProperty(Demarcator, demarcator_);
+  context.getProperty(KeepPath, keepPath_);
+  context.getProperty(AttributeStrategy, attributeStrategy_);
 
   validatePropertyOptions();
 
   if (mergeStrategy_ == merge_content_options::MERGE_STRATEGY_DEFRAGMENT) {
     binManager_.setFileCount(FRAGMENT_COUNT_ATTRIBUTE);
   }
-  logger_->log_debug("Merge Content: Strategy [%s] Format [%s] Correlation Attribute [%s] Delimiter [%s]", mergeStrategy_, mergeFormat_, correlationAttributeName_, delimiterStrategy_);
-  logger_->log_debug("Merge Content: Footer [%s] Header [%s] Demarcator [%s] KeepPath [%d]", footer_, header_, demarcator_, keepPath_);
+  logger_->log_debug("Merge Content: Strategy [{}] Format [{}] Correlation Attribute [{}] Delimiter [{}]", mergeStrategy_, mergeFormat_, correlationAttributeName_, delimiterStrategy_);
+  logger_->log_debug("Merge Content: Footer [{}] Header [{}] Demarcator [{}] KeepPath [{}]", footer_, header_, demarcator_, keepPath_);
 
   if (mergeFormat_ != merge_content_options::MERGE_FORMAT_CONCAT_VALUE) {
     if (!header_.empty()) {
-      logger_->log_warn("Header property only works with the Binary Concatenation format, value [%s] is ignored", header_);
+      logger_->log_warn("Header property only works with the Binary Concatenation format, value [{}] is ignored", header_);
     }
     if (!footer_.empty()) {
-      logger_->log_warn("Footer property only works with the Binary Concatenation format, value [%s] is ignored", footer_);
+      logger_->log_warn("Footer property only works with the Binary Concatenation format, value [{}] is ignored", footer_);
     }
     if (!demarcator_.empty()) {
-      logger_->log_warn("Demarcator property only works with the Binary Concatenation format, value [%s] is ignored", demarcator_);
+      logger_->log_warn("Demarcator property only works with the Binary Concatenation format, value [{}] is ignored", demarcator_);
     }
   }
 
@@ -103,7 +103,7 @@ void MergeContent::onSchedule(core::ProcessContext *context, core::ProcessSessio
 void MergeContent::validatePropertyOptions() {
   if (mergeStrategy_ != merge_content_options::MERGE_STRATEGY_DEFRAGMENT &&
       mergeStrategy_ != merge_content_options::MERGE_STRATEGY_BIN_PACK) {
-    logger_->log_error("Merge strategy not supported %s", mergeStrategy_);
+    logger_->log_error("Merge strategy not supported {}", mergeStrategy_);
     throw minifi::Exception(ExceptionType::PROCESSOR_EXCEPTION, "Invalid merge strategy: " + attributeStrategy_);
   }
 
@@ -111,19 +111,19 @@ void MergeContent::validatePropertyOptions() {
       mergeFormat_ != merge_content_options::MERGE_FORMAT_TAR_VALUE &&
       mergeFormat_ != merge_content_options::MERGE_FORMAT_ZIP_VALUE &&
       mergeFormat_ != merge_content_options::MERGE_FORMAT_FLOWFILE_STREAM_V3_VALUE) {
-    logger_->log_error("Merge format not supported %s", mergeFormat_);
+    logger_->log_error("Merge format not supported {}", mergeFormat_);
     throw minifi::Exception(ExceptionType::PROCESSOR_EXCEPTION, "Invalid merge format: " + mergeFormat_);
   }
 
   if (delimiterStrategy_ != merge_content_options::DELIMITER_STRATEGY_FILENAME &&
       delimiterStrategy_ != merge_content_options::DELIMITER_STRATEGY_TEXT) {
-    logger_->log_error("Delimiter strategy not supported %s", delimiterStrategy_);
+    logger_->log_error("Delimiter strategy not supported {}", delimiterStrategy_);
     throw minifi::Exception(ExceptionType::PROCESSOR_EXCEPTION, "Invalid delimiter strategy: " + delimiterStrategy_);
   }
 
   if (attributeStrategy_ != merge_content_options::ATTRIBUTE_STRATEGY_KEEP_COMMON &&
       attributeStrategy_ != merge_content_options::ATTRIBUTE_STRATEGY_KEEP_ALL_UNIQUE) {
-    logger_->log_error("Attribute strategy not supported %s", attributeStrategy_);
+    logger_->log_error("Attribute strategy not supported {}", attributeStrategy_);
     throw minifi::Exception(ExceptionType::PROCESSOR_EXCEPTION, "Invalid attribute strategy: " + attributeStrategy_);
   }
 }
@@ -152,7 +152,7 @@ bool MergeContent::checkDefragment(std::unique_ptr<Bin> &bin) {
     std::string fragCount;
     if (!front->getAttribute(BinFiles::FRAGMENT_COUNT_ATTRIBUTE, fragCount))
       return false;
-    int fragCountInt;
+    int fragCountInt = 0;
     try {
       fragCountInt = std::stoi(fragCount);
     }
@@ -187,7 +187,7 @@ bool MergeContent::checkDefragment(std::unique_ptr<Bin> &bin) {
   return true;
 }
 
-void MergeContent::onTrigger(core::ProcessContext *context, core::ProcessSession *session) {
+void MergeContent::onTrigger(core::ProcessContext& context, core::ProcessSession& session) {
   BinFiles::onTrigger(context, session);
 }
 
@@ -220,11 +220,11 @@ bool MergeContent::processBin(core::ProcessSession &session, std::unique_ptr<Bin
     }
   });
   if (attributeStrategy_ == merge_content_options::ATTRIBUTE_STRATEGY_KEEP_COMMON) {
-    KeepOnlyCommonAttributesMerger(bin->getFlowFile()).mergeAttributes(session, merge_flow);
+    KeepOnlyCommonAttributesMerger(bin->getFlowFile()).mergeAttributes(session, *merge_flow);
   } else if (attributeStrategy_ == merge_content_options::ATTRIBUTE_STRATEGY_KEEP_ALL_UNIQUE) {
-    KeepAllUniqueAttributesMerger(bin->getFlowFile()).mergeAttributes(session, merge_flow);
+    KeepAllUniqueAttributesMerger(bin->getFlowFile()).mergeAttributes(session, *merge_flow);
   } else {
-    logger_->log_error("Attribute strategy not supported %s", attributeStrategy_);
+    logger_->log_error("Attribute strategy not supported {}", attributeStrategy_);
     return false;
   }
 
@@ -250,21 +250,21 @@ bool MergeContent::processBin(core::ProcessSession &session, std::unique_ptr<Bin
     mergeBin = std::make_unique<ZipMerge>();
     mimeType = "application/zip";
   } else {
-    logger_->log_error("Merge format not supported %s", mergeFormat_);
+    logger_->log_error("Merge format not supported {}", mergeFormat_);
     return false;
   }
 
   try {
     mergeBin->merge(session, bin->getFlowFile(), *serializer, merge_flow);
-    session.putAttribute(merge_flow, core::SpecialFlowAttribute::MIME_TYPE, mimeType);
+    session.putAttribute(*merge_flow, core::SpecialFlowAttribute::MIME_TYPE, mimeType);
   } catch (const std::exception& ex) {
-    logger_->log_error("Merge Content merge catch exception, type: %s, what: %s", typeid(ex).name(), ex.what());
+    logger_->log_error("Merge Content merge catch exception, type: {}, what: {}", typeid(ex).name(), ex.what());
     return false;
   } catch (...) {
-    logger_->log_error("Merge Content merge catch exception, type: %s", getCurrentExceptionTypeName());
+    logger_->log_error("Merge Content merge catch exception, type: {}", getCurrentExceptionTypeName());
     return false;
   }
-  session.putAttribute(merge_flow, BinFiles::FRAGMENT_COUNT_ATTRIBUTE, std::to_string(bin->getSize()));
+  session.putAttribute(*merge_flow, BinFiles::FRAGMENT_COUNT_ATTRIBUTE, std::to_string(bin->getSize()));
 
   // we successfully merge the flow
   session.transfer(merge_flow, Merge);
@@ -272,7 +272,7 @@ bool MergeContent::processBin(core::ProcessSession &session, std::unique_ptr<Bin
   for (const auto& flow : flows) {
     session.transfer(flow, Original);
   }
-  logger_->log_info("Merge FlowFile record UUID %s, payload length %d", merge_flow->getUUIDStr(), merge_flow->getSize());
+  logger_->log_info("Merge FlowFile record UUID {}, payload length {}", merge_flow->getUUIDStr(), merge_flow->getSize());
 
   return true;
 }
@@ -292,7 +292,7 @@ void BinaryConcatenationMerge::merge(core::ProcessSession &session,
     flows.front()->getAttribute(BinFiles::SEGMENT_ORIGINAL_FILENAME, fileName);
   }
   if (!fileName.empty())
-    session.putAttribute(merge_flow, core::SpecialFlowAttribute::FILENAME, fileName);
+    session.putAttribute(*merge_flow, core::SpecialFlowAttribute::FILENAME, fileName);
 }
 
 void TarMerge::merge(core::ProcessSession &session,
@@ -307,7 +307,7 @@ void TarMerge::merge(core::ProcessSession &session,
   }
   if (!fileName.empty()) {
     fileName += ".tar";
-    session.putAttribute(merge_flow, core::SpecialFlowAttribute::FILENAME, fileName);
+    session.putAttribute(*merge_flow, core::SpecialFlowAttribute::FILENAME, fileName);
   }
 }
 
@@ -323,11 +323,11 @@ void ZipMerge::merge(core::ProcessSession &session,
   }
   if (!fileName.empty()) {
     fileName += ".zip";
-    session.putAttribute(merge_flow, core::SpecialFlowAttribute::FILENAME, fileName);
+    session.putAttribute(*merge_flow, core::SpecialFlowAttribute::FILENAME, fileName);
   }
 }
 
-void AttributeMerger::mergeAttributes(core::ProcessSession &session, const std::shared_ptr<core::FlowFile> &merge_flow) {
+void AttributeMerger::mergeAttributes(core::ProcessSession &session, core::FlowFile& merge_flow) {
   for (const auto& pair : getMergedAttributes()) {
     session.putAttribute(merge_flow, pair.first, pair.second);
   }
@@ -358,7 +358,7 @@ void KeepAllUniqueAttributesMerger::processFlowFile(const std::shared_ptr<core::
       continue;
     }
     std::map<std::string, std::string>::iterator insertion_res;
-    bool insertion_happened;
+    bool insertion_happened = false;
     std::tie(insertion_res, insertion_happened) = merged_attributes.insert(attr);
     if (!insertion_happened && insertion_res->second != attr.second) {
       merged_attributes.erase(insertion_res);
