@@ -220,7 +220,7 @@ class ArchiveMerge {
           if (flow->getAttribute(BinFiles::TAR_PERMISSIONS_ATTRIBUTE, perm)) {
             try {
               permInt = std::stoi(perm);
-              logger_->log_debug("Merge Tar File %s permission %s", fileName, perm);
+              logger_->log_debug("Merge Tar File {} permission {}", fileName, perm);
               archive_entry_set_perm(entry, (mode_t) permInt);
             } catch (...) {
             }
@@ -256,7 +256,7 @@ class AttributeMerger {
  public:
   explicit AttributeMerger(std::deque<std::shared_ptr<org::apache::nifi::minifi::core::FlowFile>> &flows)
     : flows_(flows) {}
-  void mergeAttributes(core::ProcessSession &session, const std::shared_ptr<core::FlowFile> &merge_flow);
+  void mergeAttributes(core::ProcessSession &session, core::FlowFile& merge_flow);
   virtual ~AttributeMerger() = default;
 
  protected:
@@ -381,8 +381,8 @@ class MergeContent : public processors::BinFiles {
 
   ADD_COMMON_VIRTUAL_FUNCTIONS_FOR_PROCESSORS
 
-  void onSchedule(core::ProcessContext *context, core::ProcessSessionFactory *sessionFactory) override;
-  void onTrigger(core::ProcessContext *context, core::ProcessSession *session) override;
+  void onSchedule(core::ProcessContext& context, core::ProcessSessionFactory& sessionFactory) override;
+  void onTrigger(core::ProcessContext& context, core::ProcessSession& session) override;
   void initialize() override;
   bool processBin(core::ProcessSession &session, std::unique_ptr<Bin> &bin) override;
 
