@@ -40,8 +40,8 @@ using core::logging::Logger;
 
 class UnfocusArchiveEntry : public core::Processor {
  public:
-  explicit UnfocusArchiveEntry(std::string name, const utils::Identifier& uuid = {})
-      : core::Processor(std::move(name), uuid) {
+  explicit UnfocusArchiveEntry(std::string_view name, const utils::Identifier& uuid = {})
+      : core::Processor(name, uuid) {
   }
   ~UnfocusArchiveEntry() override = default;
 
@@ -59,7 +59,7 @@ class UnfocusArchiveEntry : public core::Processor {
 
   ADD_COMMON_VIRTUAL_FUNCTIONS_FOR_PROCESSORS
 
-  void onTrigger(core::ProcessContext *context, core::ProcessSession *session) override;
+  void onTrigger(core::ProcessContext& context, core::ProcessSession& session) override;
   void initialize() override;
 
   //! Write callback for reconstituting lensed archive into flow file content
