@@ -219,13 +219,13 @@ class ConsumeKafka : public KafkaProcessorBase {
 
   ADD_COMMON_VIRTUAL_FUNCTIONS_FOR_PROCESSORS
 
-  explicit ConsumeKafka(std::string name, const utils::Identifier& uuid = utils::Identifier()) :
-      KafkaProcessorBase(std::move(name), uuid, core::logging::LoggerFactory<ConsumeKafka>::getLogger(uuid)) {}
+  explicit ConsumeKafka(std::string_view name, const utils::Identifier& uuid = utils::Identifier()) :
+      KafkaProcessorBase(name, uuid, core::logging::LoggerFactory<ConsumeKafka>::getLogger(uuid)) {}
 
   ~ConsumeKafka() override = default;
 
-  void onSchedule(core::ProcessContext* context, core::ProcessSessionFactory* /* sessionFactory */) override;
-  void onTrigger(core::ProcessContext* context, core::ProcessSession* session) override;
+  void onSchedule(core::ProcessContext& context, core::ProcessSessionFactory& session_factory) override;
+  void onTrigger(core::ProcessContext& context, core::ProcessSession& session) override;
   void initialize() override;
 
  private:
