@@ -102,7 +102,7 @@ class PublishKafka::Messages {
       }
       oss << "}, ";
     }
-    oss << "in-flight (" << flow_files_in_flight.size() << "): " << utils::StringUtils::join(",", flow_files_in_flight);
+    oss << "in-flight (" << flow_files_in_flight.size() << "): " << utils::string::join(",", flow_files_in_flight);
     return oss.str();
   }
 
@@ -113,7 +113,7 @@ class PublishKafka::Messages {
     std::unique_lock<std::mutex> lock(mutex_);
     cv_.wait(lock, [this, &lock] {
       if (logger_->should_log(core::logging::LOG_LEVEL::trace)) {
-        logger_->log_trace("%s", logStatus(lock));
+        logger_->log_trace("{}", logStatus(lock));
       }
       return interrupted_ || std::all_of(std::begin(this->flow_files_), std::end(this->flow_files_), [](const FlowFileResult& flow_file) {
         return flow_file.flow_file_error || std::all_of(std::begin(flow_file.messages), std::end(flow_file.messages), [](const MessageResult& message) {
@@ -130,7 +130,7 @@ class PublishKafka::Messages {
     try {
       return fun(flow_files_.at(index));
     } catch(const std::exception& ex) {
-      logger_->log_warn("Messages::modifyResult exception: %s", ex.what());
+      logger_->log_warn("Messages::modifyResult exception: {}", ex.what());
       throw;
     }
   }
@@ -190,7 +190,7 @@ class ReadCallback {
 
     for (const auto& kv : flow_file.getAttributes()) {
       if (attribute_name_regex && utils::regexMatch(kv.first, *attribute_name_regex)) {
-        rd_kafka_header_add(result, kv.first.c_str(), kv.first.size(), kv.second.c_str(), kv.second.size());
+        rd_kafka_header_add(result, kv.first.c_str(), gsl::narrow<ssize_t>(kv.first.size()), kv.second.c_str(), gsl::narrow<ssize_t>(kv.second.size()));
       }
     }
     return rd_kafka_headers_unique_ptr{ result };
@@ -206,9 +206,9 @@ class ReadCallback {
         message.err_code = rkmessage->err;
         message.status = message.err_code == 0 ? MessageStatus::Success : MessageStatus::Error;
         if (message.err_code != RD_KAFKA_RESP_ERR_NO_ERROR) {
-          logger->log_warn("delivery callback, flow file #%zu/segment #%zu: %s", flow_file_index_copy, segment_num, rd_kafka_err2str(message.err_code));
+          logger->log_warn("delivery callback, flow file #{}/segment #{}: {}", flow_file_index_copy, segment_num, rd_kafka_err2str(message.err_code));
         } else {
-          logger->log_debug("delivery callback, flow file #%zu/segment #%zu: success", flow_file_index_copy, segment_num);
+          logger->log_debug("delivery callback, flow file #{}/segment #{}: success", flow_file_index_copy, segment_num);
         }
       });
     };
@@ -217,7 +217,7 @@ class ReadCallback {
 
     allocate_message_object(segment_num);
 
-    const gsl::owner<rd_kafka_headers_t*> hdrs_copy = rd_kafka_headers_copy(hdrs.get());
+    const auto hdrs_copy = gsl::owner<rd_kafka_headers_t*>(rd_kafka_headers_copy(hdrs.get()));
     const auto err = rd_kafka_producev(rk_, RD_KAFKA_V_RKT(rkt_), RD_KAFKA_V_PARTITION(RD_KAFKA_PARTITION_UA), RD_KAFKA_V_MSGFLAGS(RD_KAFKA_MSG_F_COPY), RD_KAFKA_V_VALUE(buffer.data(), buflen),
         RD_KAFKA_V_HEADERS(hdrs_copy), RD_KAFKA_V_KEY(key_.c_str(), key_.size()), RD_KAFKA_V_OPAQUE(callback_ptr.get()), RD_KAFKA_V_END);
     if (err == RD_KAFKA_RESP_ERR_NO_ERROR) {
@@ -228,7 +228,7 @@ class ReadCallback {
       // in case of failure, rd_kafka_producev doesn't take ownership of the headers, so we need to delete them
       rd_kafka_headers_destroy(hdrs_copy);
     }
-    logger_->log_trace("produce enqueued flow file #%zu/segment #%zu: %s", flow_file_index_, segment_num, rd_kafka_err2str(err));
+    logger_->log_trace("produce enqueued flow file #{}/segment #{}: {}", flow_file_index_, segment_num, rd_kafka_err2str(err));
     return err;
   }
 
@@ -255,8 +255,11 @@ class ReadCallback {
       logger_(std::move(logger))
   { }
 
+  ReadCallback(ReadCallback&&) = delete;
   ReadCallback(const ReadCallback&) = delete;
-  ReadCallback& operator=(ReadCallback) = delete;
+  ReadCallback& operator=(ReadCallback&&) = delete;
+  ReadCallback& operator=(const ReadCallback&) = delete;
+  ~ReadCallback() = default;
 
   int64_t operator()(const std::shared_ptr<io::InputStream>& stream) {
     std::vector<std::byte> buffer;
@@ -303,7 +306,7 @@ class ReadCallback {
         error_ = rd_kafka_err2str(err);
         return read_size_;
       }
-      read_size_ += readRet;
+      read_size_ += gsl::narrow<uint32_t>(readRet);
     }
     return read_size_;
   }
@@ -336,7 +339,7 @@ void messageDeliveryCallback(rd_kafka_t* rk, const rd_kafka_message_t* rkmessage
   try {
     (*func)(rk, rkmessage);
   } catch (...) { }
-  delete func;
+  delete func;  // NOLINT(cppcoreguidelines-owning-memory)
 }
 }  // namespace
 
@@ -345,38 +348,38 @@ void PublishKafka::initialize() {
   setSupportedRelationships(Relationships);
 }
 
-void PublishKafka::onSchedule(const std::shared_ptr<core::ProcessContext> &context, const std::shared_ptr<core::ProcessSessionFactory>& /*sessionFactory*/) {
+void PublishKafka::onSchedule(core::ProcessContext& context, core::ProcessSessionFactory&) {
   interrupted_ = false;
 
   // Try to get a KafkaConnection
   std::string client_id;
   std::string brokers;
-  if (!context->getProperty(ClientName, client_id, nullptr)) {
+  if (!context.getProperty(ClientName, client_id, nullptr)) {
     throw Exception(PROCESS_SCHEDULE_EXCEPTION, "Client Name property missing or invalid");
   }
-  if (!context->getProperty(SeedBrokers, brokers, nullptr)) {
+  if (!context.getProperty(SeedBrokers, brokers, nullptr)) {
     throw Exception(PROCESS_SCHEDULE_EXCEPTION, "Known Brokers property missing or invalid");
   }
 
   // Get some properties not (only) used directly to set up librdkafka
 
   // Batch Size
-  context->getProperty(BatchSize, batch_size_);
-  logger_->log_debug("PublishKafka: Batch Size [%lu]", batch_size_);
+  context.getProperty(BatchSize, batch_size_);
+  logger_->log_debug("PublishKafka: Batch Size [{}]", batch_size_);
 
   // Target Batch Payload Size
-  context->getProperty(TargetBatchPayloadSize, target_batch_payload_size_);
-  logger_->log_debug("PublishKafka: Target Batch Payload Size [%llu]", target_batch_payload_size_);
+  context.getProperty(TargetBatchPayloadSize, target_batch_payload_size_);
+  logger_->log_debug("PublishKafka: Target Batch Payload Size [{}]", target_batch_payload_size_);
 
   // Max Flow Segment Size
-  context->getProperty(MaxFlowSegSize, max_flow_seg_size_);
-  logger_->log_debug("PublishKafka: Max Flow Segment Size [%llu]", max_flow_seg_size_);
+  context.getProperty(MaxFlowSegSize, max_flow_seg_size_);
+  logger_->log_debug("PublishKafka: Max Flow Segment Size [{}]", max_flow_seg_size_);
 
   // Attributes to Send as Headers
   std::string value;
-  if (context->getProperty(AttributeNameRegex, value) && !value.empty()) {
+  if (context.getProperty(AttributeNameRegex, value) && !value.empty()) {
     attributeNameRegex_ = utils::Regex(value);
-    logger_->log_debug("PublishKafka: AttributeNameRegex [%s]", value);
+    logger_->log_debug("PublishKafka: AttributeNameRegex [{}]", value);
   }
 
   key_.brokers_ = brokers;
@@ -386,8 +389,8 @@ void PublishKafka::onSchedule(const std::shared_ptr<core::ProcessContext> &conte
   configureNewConnection(context);
 
   std::string message_key_field;
-  if (context->getProperty(MessageKeyField, message_key_field) && !message_key_field.empty()) {
-    logger_->log_error("The %s property is set. This property is DEPRECATED and has no effect; please use Kafka Key instead.", std::string{MessageKeyField.name});
+  if (context.getProperty(MessageKeyField, message_key_field) && !message_key_field.empty()) {
+    logger_->log_error("The {} property is set. This property is DEPRECATED and has no effect; please use Kafka Key instead.", MessageKeyField.name);
   }
 
   logger_->log_debug("Successfully configured PublishKafka");
@@ -412,12 +415,12 @@ void PublishKafka::notifyStop() {
 }
 
 
-bool PublishKafka::configureNewConnection(const std::shared_ptr<core::ProcessContext> &context) {
+bool PublishKafka::configureNewConnection(core::ProcessContext& context) {
   std::string value;
-  int64_t valInt;
+  int64_t valInt = 0;
   std::string valueConf;
   std::array<char, 512U> errstr{};
-  rd_kafka_conf_res_t result;
+  rd_kafka_conf_res_t result = RD_KAFKA_CONF_OK;
   const char* const PREFIX_ERROR_MSG = "PublishKafka: configure error result: ";
 
   std::unique_ptr<rd_kafka_conf_t, rd_kafka_conf_deleter> conf_{ rd_kafka_conf_new() };
@@ -431,9 +434,9 @@ bool PublishKafka::configureNewConnection(const std::shared_ptr<core::ProcessCon
     throw Exception(PROCESS_SCHEDULE_EXCEPTION, "There are no brokers");
   }
   result = rd_kafka_conf_set(conf_.get(), "bootstrap.servers", key->brokers_.c_str(), errstr.data(), errstr.size());
-  logger_->log_debug("PublishKafka: bootstrap.servers [%s]", key->brokers_);
+  logger_->log_debug("PublishKafka: bootstrap.servers [{}]", key->brokers_);
   if (result != RD_KAFKA_CONF_OK) {
-    auto error_msg = utils::StringUtils::join_pack(PREFIX_ERROR_MSG, errstr.data());
+    auto error_msg = utils::string::join_pack(PREFIX_ERROR_MSG, errstr.data());
     throw Exception(PROCESS_SCHEDULE_EXCEPTION, error_msg);
   }
 
@@ -441,105 +444,105 @@ bool PublishKafka::configureNewConnection(const std::shared_ptr<core::ProcessCon
     throw Exception(PROCESS_SCHEDULE_EXCEPTION, "Client id is empty");
   }
   result = rd_kafka_conf_set(conf_.get(), "client.id", key->client_id_.c_str(), errstr.data(), errstr.size());
-  logger_->log_debug("PublishKafka: client.id [%s]", key->client_id_);
+  logger_->log_debug("PublishKafka: client.id [{}]", key->client_id_);
   if (result != RD_KAFKA_CONF_OK) {
-    auto error_msg = utils::StringUtils::join_pack(PREFIX_ERROR_MSG, errstr.data());
+    auto error_msg = utils::string::join_pack(PREFIX_ERROR_MSG, errstr.data());
     throw Exception(PROCESS_SCHEDULE_EXCEPTION, error_msg);
   }
 
   value = "";
-  if (context->getProperty(DebugContexts, value) && !value.empty()) {
+  if (context.getProperty(DebugContexts, value) && !value.empty()) {
     result = rd_kafka_conf_set(conf_.get(), "debug", value.c_str(), errstr.data(), errstr.size());
-    logger_->log_debug("PublishKafka: debug [%s]", value);
+    logger_->log_debug("PublishKafka: debug [{}]", value);
     if (result != RD_KAFKA_CONF_OK) {
-      auto error_msg = utils::StringUtils::join_pack(PREFIX_ERROR_MSG, errstr.data());
+      auto error_msg = utils::string::join_pack(PREFIX_ERROR_MSG, errstr.data());
       throw Exception(PROCESS_SCHEDULE_EXCEPTION, error_msg);
     }
   }
 
   value = "";
-  if (context->getProperty(MaxMessageSize, value) && !value.empty()) {
+  if (context.getProperty(MaxMessageSize, value) && !value.empty()) {
     result = rd_kafka_conf_set(conf_.get(), "message.max.bytes", value.c_str(), errstr.data(), errstr.size());
-    logger_->log_debug("PublishKafka: message.max.bytes [%s]", value);
+    logger_->log_debug("PublishKafka: message.max.bytes [{}]", value);
     if (result != RD_KAFKA_CONF_OK) {
-      auto error_msg = utils::StringUtils::join_pack(PREFIX_ERROR_MSG, errstr.data());
+      auto error_msg = utils::string::join_pack(PREFIX_ERROR_MSG, errstr.data());
       throw Exception(PROCESS_SCHEDULE_EXCEPTION, error_msg);
     }
   }
   value = "";
-  uint32_t int_val;
-  if (context->getProperty(QueueBufferMaxMessage, int_val)) {
+  uint32_t int_val = 0;
+  if (context.getProperty(QueueBufferMaxMessage, int_val)) {
     if (int_val < batch_size_) {
       throw Exception(PROCESS_SCHEDULE_EXCEPTION, "Invalid configuration: Batch Size cannot be larger than Queue Max Message");
     }
 
     value = std::to_string(int_val);
     result = rd_kafka_conf_set(conf_.get(), "queue.buffering.max.messages", value.c_str(), errstr.data(), errstr.size());
-    logger_->log_debug("PublishKafka: queue.buffering.max.messages [%s]", value);
+    logger_->log_debug("PublishKafka: queue.buffering.max.messages [{}]", value);
     if (result != RD_KAFKA_CONF_OK) {
-      auto error_msg = utils::StringUtils::join_pack(PREFIX_ERROR_MSG, errstr.data());
+      auto error_msg = utils::string::join_pack(PREFIX_ERROR_MSG, errstr.data());
       throw Exception(PROCESS_SCHEDULE_EXCEPTION, error_msg);
     }
   }
   value = "";
-  if (context->getProperty(QueueBufferMaxSize, value) && !value.empty() && core::Property::StringToInt(value, valInt)) {
+  if (context.getProperty(QueueBufferMaxSize, value) && !value.empty() && core::Property::StringToInt(value, valInt)) {
     valInt = valInt / 1024;
     valueConf = std::to_string(valInt);
     result = rd_kafka_conf_set(conf_.get(), "queue.buffering.max.kbytes", valueConf.c_str(), errstr.data(), errstr.size());
-    logger_->log_debug("PublishKafka: queue.buffering.max.kbytes [%s]", valueConf);
+    logger_->log_debug("PublishKafka: queue.buffering.max.kbytes [{}]", valueConf);
     if (result != RD_KAFKA_CONF_OK) {
-      auto error_msg = utils::StringUtils::join_pack(PREFIX_ERROR_MSG, errstr.data());
+      auto error_msg = utils::string::join_pack(PREFIX_ERROR_MSG, errstr.data());
       throw Exception(PROCESS_SCHEDULE_EXCEPTION, error_msg);
     }
   }
 
-  if (auto queue_buffer_max_time = context->getProperty<core::TimePeriodValue>(QueueBufferMaxTime)) {
+  if (auto queue_buffer_max_time = context.getProperty<core::TimePeriodValue>(QueueBufferMaxTime)) {
     valueConf = std::to_string(queue_buffer_max_time->getMilliseconds().count());
     result = rd_kafka_conf_set(conf_.get(), "queue.buffering.max.ms", valueConf.c_str(), errstr.data(), errstr.size());
-    logger_->log_debug("PublishKafka: queue.buffering.max.ms [%s]", valueConf);
+    logger_->log_debug("PublishKafka: queue.buffering.max.ms [{}]", valueConf);
     if (result != RD_KAFKA_CONF_OK) {
-      auto error_msg = utils::StringUtils::join_pack(PREFIX_ERROR_MSG, errstr.data());
+      auto error_msg = utils::string::join_pack(PREFIX_ERROR_MSG, errstr.data());
       throw Exception(PROCESS_SCHEDULE_EXCEPTION, error_msg);
     }
   }
   value = "";
-  if (context->getProperty(BatchSize, value) && !value.empty()) {
+  if (context.getProperty(BatchSize, value) && !value.empty()) {
     result = rd_kafka_conf_set(conf_.get(), "batch.num.messages", value.c_str(), errstr.data(), errstr.size());
-    logger_->log_debug("PublishKafka: batch.num.messages [%s]", value);
+    logger_->log_debug("PublishKafka: batch.num.messages [{}]", value);
     if (result != RD_KAFKA_CONF_OK) {
-      auto error_msg = utils::StringUtils::join_pack(PREFIX_ERROR_MSG, errstr.data());
+      auto error_msg = utils::string::join_pack(PREFIX_ERROR_MSG, errstr.data());
       throw Exception(PROCESS_SCHEDULE_EXCEPTION, error_msg);
     }
   }
   value = "";
-  if (context->getProperty(CompressCodec, value) && !value.empty() && value != "none") {
+  if (context.getProperty(CompressCodec, value) && !value.empty() && value != "none") {
     result = rd_kafka_conf_set(conf_.get(), "compression.codec", value.c_str(), errstr.data(), errstr.size());
-    logger_->log_debug("PublishKafka: compression.codec [%s]", value);
+    logger_->log_debug("PublishKafka: compression.codec [{}]", value);
     if (result != RD_KAFKA_CONF_OK) {
-      auto error_msg = utils::StringUtils::join_pack(PREFIX_ERROR_MSG, errstr.data());
+      auto error_msg = utils::string::join_pack(PREFIX_ERROR_MSG, errstr.data());
       throw Exception(PROCESS_SCHEDULE_EXCEPTION, error_msg);
     }
   }
 
-  setKafkaAuthenticationParameters(*context, gsl::make_not_null(conf_.get()));
+  setKafkaAuthenticationParameters(context, gsl::make_not_null(conf_.get()));
 
   // Add all of the dynamic properties as librdkafka configurations
-  const auto &dynamic_prop_keys = context->getDynamicPropertyKeys();
-  logger_->log_info("PublishKafka registering %d librdkafka dynamic properties", dynamic_prop_keys.size());
+  const auto &dynamic_prop_keys = context.getDynamicPropertyKeys();
+  logger_->log_info("PublishKafka registering {} librdkafka dynamic properties", dynamic_prop_keys.size());
 
   for (const auto &prop_key : dynamic_prop_keys) {
     core::Property dynamic_property_key{prop_key, "dynamic property"};
     dynamic_property_key.setSupportsExpressionLanguage(true);
     std::string dynamic_property_value;
-    if (context->getDynamicProperty(dynamic_property_key, dynamic_property_value, nullptr) && !dynamic_property_value.empty()) {
-      logger_->log_debug("PublishKafka: DynamicProperty: [%s] -> [%s]", prop_key, dynamic_property_value);
+    if (context.getDynamicProperty(dynamic_property_key, dynamic_property_value, nullptr) && !dynamic_property_value.empty()) {
+      logger_->log_debug("PublishKafka: DynamicProperty: [{}] -> [{}]", prop_key, dynamic_property_value);
       result = rd_kafka_conf_set(conf_.get(), prop_key.c_str(), dynamic_property_value.c_str(), errstr.data(), errstr.size());
       if (result != RD_KAFKA_CONF_OK) {
-        auto error_msg = utils::StringUtils::join_pack(PREFIX_ERROR_MSG, errstr.data());
+        auto error_msg = utils::string::join_pack(PREFIX_ERROR_MSG, errstr.data());
         throw Exception(PROCESS_SCHEDULE_EXCEPTION, error_msg);
       }
     } else {
-      logger_->log_warn("PublishKafka Dynamic Property '%s' is empty and therefore will not be configured", prop_key);
+      logger_->log_warn("PublishKafka Dynamic Property '{}' is empty and therefore will not be configured", prop_key);
     }
   }
 
@@ -550,9 +553,9 @@ bool PublishKafka::configureNewConnection(const std::shared_ptr<core::ProcessCon
   rd_kafka_conf_set_log_cb(conf_.get(), &KafkaConnection::logCallback);
 
   // The producer takes ownership of the configuration, we must not free it
-  gsl::owner<rd_kafka_t*> producer = rd_kafka_new(RD_KAFKA_PRODUCER, conf_.release(), errstr.data(), errstr.size());
+  const auto producer = gsl::owner<rd_kafka_t*>(rd_kafka_new(RD_KAFKA_PRODUCER, conf_.release(), errstr.data(), errstr.size()));
   if (producer == nullptr) {
-    auto error_msg = utils::StringUtils::join_pack("Failed to create Kafka producer ", errstr.data());
+    auto error_msg = utils::string::join_pack("Failed to create Kafka producer ", errstr.data());
     throw Exception(PROCESS_SCHEDULE_EXCEPTION, error_msg);
   }
 
@@ -561,20 +564,20 @@ bool PublishKafka::configureNewConnection(const std::shared_ptr<core::ProcessCon
   return true;
 }
 
-bool PublishKafka::createNewTopic(const std::shared_ptr<core::ProcessContext> &context, const std::string& topic_name, const std::shared_ptr<core::FlowFile>& flow_file) {
+bool PublishKafka::createNewTopic(core::ProcessContext& context, const std::string& topic_name, const std::shared_ptr<core::FlowFile>& flow_file) {
   std::unique_ptr<rd_kafka_topic_conf_t, rd_kafka_topic_conf_deleter> topic_conf_{ rd_kafka_topic_conf_new() };
   if (topic_conf_ == nullptr) {
     logger_->log_error("Failed to create rd_kafka_topic_conf_t object");
     return false;
   }
 
-  rd_kafka_conf_res_t result;
+  rd_kafka_conf_res_t result = RD_KAFKA_CONF_OK;
   std::string value;
   std::array<char, 512U> errstr{};
   std::string valueConf;
 
   value = "";
-  if (context->getProperty(DeliveryGuarantee, value, flow_file) && !value.empty()) {
+  if (context.getProperty(DeliveryGuarantee, value, flow_file.get()) && !value.empty()) {
     /*
      * Because of a previous error in this processor, the default value of this property was "DELIVERY_ONE_NODE".
      * As this is not a valid value for "request.required.acks", the following rd_kafka_topic_conf_set call failed,
@@ -591,38 +594,38 @@ bool PublishKafka::createNewTopic(const std::shared_ptr<core::ProcessContext> &c
                         "If you want to wait for one acknowledgment use '1' as the property.");
     }
     result = rd_kafka_topic_conf_set(topic_conf_.get(), "request.required.acks", value.c_str(), errstr.data(), errstr.size());
-    logger_->log_debug("PublishKafka: request.required.acks [%s]", value);
+    logger_->log_debug("PublishKafka: request.required.acks [{}]", value);
     if (result != RD_KAFKA_CONF_OK) {
-      logger_->log_error("PublishKafka: configure request.required.acks error result [%s]", errstr.data());
+      logger_->log_error("PublishKafka: configure request.required.acks error result [{}]", errstr.data());
       return false;
     }
   }
 
-  if (auto request_timeout = context->getProperty<core::TimePeriodValue>(RequestTimeOut)) {
+  if (auto request_timeout = context.getProperty<core::TimePeriodValue>(RequestTimeOut)) {
     valueConf = std::to_string(request_timeout->getMilliseconds().count());
     result = rd_kafka_topic_conf_set(topic_conf_.get(), "request.timeout.ms", valueConf.c_str(), errstr.data(), errstr.size());
-    logger_->log_debug("PublishKafka: request.timeout.ms [%s]", valueConf);
+    logger_->log_debug("PublishKafka: request.timeout.ms [{}]", valueConf);
     if (result != RD_KAFKA_CONF_OK) {
-      logger_->log_error("PublishKafka: configure request.timeout.ms error result [%s]", errstr.data());
+      logger_->log_error("PublishKafka: configure request.timeout.ms error result [{}]", errstr.data());
       return false;
     }
   }
 
-  if (auto message_timeout = context->getProperty<core::TimePeriodValue>(MessageTimeOut)) {
+  if (auto message_timeout = context.getProperty<core::TimePeriodValue>(MessageTimeOut)) {
     valueConf = std::to_string(message_timeout->getMilliseconds().count());
     result = rd_kafka_topic_conf_set(topic_conf_.get(), "message.timeout.ms", valueConf.c_str(), errstr.data(), errstr.size());
-    logger_->log_debug("PublishKafka: message.timeout.ms [%s]", valueConf);
+    logger_->log_debug("PublishKafka: message.timeout.ms [{}]", valueConf);
     if (result != RD_KAFKA_CONF_OK) {
-      logger_->log_error("PublishKafka: configure message.timeout.ms error result [%s]", errstr.data());
+      logger_->log_error("PublishKafka: configure message.timeout.ms error result [{}]", errstr.data());
       return false;
     }
   }
 
   // The topic takes ownership of the configuration, we must not free it
-  gsl::owner<rd_kafka_topic_t*> topic_reference = rd_kafka_topic_new(conn_->getConnection(), topic_name.c_str(), topic_conf_.release());
+  const auto topic_reference = gsl::owner<rd_kafka_topic_t*>(rd_kafka_topic_new(conn_->getConnection(), topic_name.c_str(), topic_conf_.release()));
   if (topic_reference == nullptr) {
     rd_kafka_resp_err_t resp_err = rd_kafka_last_error();
-    logger_->log_error("PublishKafka: failed to create topic %s, error: %s", topic_name.c_str(), rd_kafka_err2str(resp_err));
+    logger_->log_error("PublishKafka: failed to create topic {}, error: {}", topic_name.c_str(), rd_kafka_err2str(resp_err));
     return false;
   }
 
@@ -649,11 +652,11 @@ std::optional<utils::net::SslData> PublishKafka::getSslData(core::ProcessContext
   return ssl_data;
 }
 
-void PublishKafka::onTrigger(const std::shared_ptr<core::ProcessContext> &context, const std::shared_ptr<core::ProcessSession> &session) {
+void PublishKafka::onTrigger(core::ProcessContext& context, core::ProcessSession& session) {
   // Check whether we have been interrupted
   if (interrupted_) {
     logger_->log_info("The processor has been interrupted, not running onTrigger");
-    context->yield();
+    context.yield();
     return;
   }
 
@@ -664,7 +667,7 @@ void PublishKafka::onTrigger(const std::shared_ptr<core::ProcessContext> &contex
   uint64_t actual_bytes = 0U;
   std::vector<std::shared_ptr<core::FlowFile>> flowFiles;
   for (uint32_t i = 0; i < batch_size_; i++) {
-    std::shared_ptr<core::FlowFile> flowFile = session->get();
+    std::shared_ptr<core::FlowFile> flowFile = session.get();
     if (flowFile == nullptr) {
       break;
     }
@@ -675,10 +678,10 @@ void PublishKafka::onTrigger(const std::shared_ptr<core::ProcessContext> &contex
     }
   }
   if (flowFiles.empty()) {
-    context->yield();
+    context.yield();
     return;
   }
-  logger_->log_debug("Processing %lu flow files with a total size of %llu B", flowFiles.size(), actual_bytes);
+  logger_->log_debug("Processing {} flow files with a total size of {} B", flowFiles.size(), actual_bytes);
 
   auto messages = std::make_shared<Messages>(logger_);
   // We must add this to the messages set, so that it will be interrupted when notifyStop is called
@@ -698,10 +701,10 @@ void PublishKafka::onTrigger(const std::shared_ptr<core::ProcessContext> &contex
 
     // Get Topic (FlowFile-dependent EL property)
     std::string topic;
-    if (context->getProperty(Topic, topic, flowFile)) {
-      logger_->log_debug("PublishKafka: topic for flow file %s is '%s'", flowFile->getUUIDStr(), topic);
+    if (context.getProperty(Topic, topic, flowFile.get())) {
+      logger_->log_debug("PublishKafka: topic for flow file {} is '{}'", flowFile->getUUIDStr(), topic);
     } else {
-      logger_->log_error("Flow file %s does not have a valid Topic", flowFile->getUUIDStr());
+      logger_->log_error("Flow file {} does not have a valid Topic", flowFile->getUUIDStr());
       messages->modifyResult(flow_file_index, [](FlowFileResult& flow_file_result) {
         flow_file_result.flow_file_error = true;
       });
@@ -711,7 +714,7 @@ void PublishKafka::onTrigger(const std::shared_ptr<core::ProcessContext> &contex
     // Add topic to the connection if needed
     if (!conn_->hasTopic(topic)) {
       if (!createNewTopic(context, topic, flowFile)) {
-        logger_->log_error("Failed to add topic %s", topic);
+        logger_->log_error("Failed to add topic {}", topic);
         messages->modifyResult(flow_file_index, [](FlowFileResult& flow_file_result) {
           flow_file_result.flow_file_error = true;
         });
@@ -720,14 +723,14 @@ void PublishKafka::onTrigger(const std::shared_ptr<core::ProcessContext> &contex
     }
 
     std::string kafkaKey;
-    if (!context->getProperty(KafkaKey, kafkaKey, flowFile) || kafkaKey.empty()) {
+    if (!context.getProperty(KafkaKey, kafkaKey, flowFile.get()) || kafkaKey.empty()) {
       kafkaKey = flowFile->getUUIDStr();
     }
-    logger_->log_debug("PublishKafka: Message Key [%s]", kafkaKey);
+    logger_->log_debug("PublishKafka: Message Key [{}]", kafkaKey);
 
     auto thisTopic = conn_->getTopic(topic);
     if (thisTopic == nullptr) {
-      logger_->log_error("Topic %s is invalid", topic);
+      logger_->log_error("Topic {} is invalid", topic);
       messages->modifyResult(flow_file_index, [](FlowFileResult& flow_file_result) {
         flow_file_result.flow_file_error = true;
       });
@@ -735,11 +738,11 @@ void PublishKafka::onTrigger(const std::shared_ptr<core::ProcessContext> &contex
     }
 
     bool failEmptyFlowFiles = true;
-    context->getProperty(FailEmptyFlowFiles, failEmptyFlowFiles);
+    context.getProperty(FailEmptyFlowFiles, failEmptyFlowFiles);
 
     ReadCallback callback(max_flow_seg_size_, kafkaKey, thisTopic->getTopic(), conn_->getConnection(), *flowFile,
                           attributeNameRegex_, messages, flow_file_index, failEmptyFlowFiles, logger_);
-    session->read(flowFile, std::ref(callback));
+    session.read(flowFile, std::ref(callback));
 
     if (!callback.called_) {
       // workaround: call callback since ProcessSession doesn't do so for empty flow files without resource claims
@@ -747,14 +750,14 @@ void PublishKafka::onTrigger(const std::shared_ptr<core::ProcessContext> &contex
     }
 
     if (flowFile->getSize() == 0 && failEmptyFlowFiles) {
-      logger_->log_debug("Deprecated behavior, use connections to drop empty flow files! Failing empty flow file with uuid: %s", flowFile->getUUIDStr());
+      logger_->log_debug("Deprecated behavior, use connections to drop empty flow files! Failing empty flow file with uuid: {}", flowFile->getUUIDStr());
       messages->modifyResult(flow_file_index, [](FlowFileResult& flow_file_result) {
         flow_file_result.flow_file_error = true;
       });
     }
 
     if (callback.status_ < 0) {
-      logger_->log_error("Failed to send flow to kafka topic %s, error: %s", topic, callback.error_);
+      logger_->log_error("Failed to send flow to kafka topic {}, error: {}", topic, callback.error_);
       messages->modifyResult(flow_file_index, [](FlowFileResult& flow_file_result) {
         flow_file_result.flow_file_error = true;
       });
@@ -770,7 +773,7 @@ void PublishKafka::onTrigger(const std::shared_ptr<core::ProcessContext> &contex
   logger_->log_trace("PublishKafka::onTrigger waitForCompletion finish");
 
   messages->iterateFlowFiles([&](size_t index, const FlowFileResult& flow_file) {
-    bool success;
+    bool success = false;
     if (flow_file.flow_file_error) {
       success = false;
     } else {
@@ -780,19 +783,19 @@ void PublishKafka::onTrigger(const std::shared_ptr<core::ProcessContext> &contex
         switch (message.status) {
           case MessageStatus::InFlight:
             success = false;
-            logger_->log_error("Waiting for delivery confirmation was interrupted for flow file %s segment %zu",
+            logger_->log_error("Waiting for delivery confirmation was interrupted for flow file {} segment {}",
                 flowFiles[index]->getUUIDStr(),
                 segment_num);
           break;
           case MessageStatus::Error:
             success = false;
-            logger_->log_error("Failed to deliver flow file %s segment %zu, error: %s",
+            logger_->log_error("Failed to deliver flow file {} segment {}, error: {}",
                 flowFiles[index]->getUUIDStr(),
                 segment_num,
                 rd_kafka_err2str(message.err_code));
           break;
           case MessageStatus::Success:
-            logger_->log_debug("Successfully delivered flow file %s segment %zu",
+            logger_->log_debug("Successfully delivered flow file {} segment {}",
                 flowFiles[index]->getUUIDStr(),
                 segment_num);
           break;
@@ -800,10 +803,10 @@ void PublishKafka::onTrigger(const std::shared_ptr<core::ProcessContext> &contex
       }
     }
     if (success) {
-      session->transfer(flowFiles[index], Success);
+      session.transfer(flowFiles[index], Success);
     } else {
-      session->penalize(flowFiles[index]);
-      session->transfer(flowFiles[index], Failure);
+      session.penalize(flowFiles[index]);
+      session.transfer(flowFiles[index], Failure);
     }
   });
 }
