@@ -22,6 +22,7 @@
 #include "LuaScriptEngine.h"
 #include "LuaProcessSession.h"
 #include "LuaScriptProcessContext.h"
+#include "LuaLogger.h"
 #include "utils/StringUtils.h"
 
 namespace org::apache::nifi::minifi::extensions::lua {
@@ -37,9 +38,9 @@ LuaScriptEngine::LuaScriptEngine() {
       sol::lib::table,
       sol::lib::utf8,
       sol::lib::package);
-  lua_.new_usertype<core::logging::Logger>(
+  lua_.new_usertype<LuaLogger>(
       "Logger",
-      "info", &core::logging::Logger::log_info<>);
+      "info", &LuaLogger::log_info);
   lua_.new_usertype<LuaProcessSession>(
       "ProcessSession",
       "create", static_cast<std::shared_ptr<LuaScriptFlowFile> (LuaProcessSession::*)()>(&LuaProcessSession::create),
@@ -73,9 +74,9 @@ LuaScriptEngine::LuaScriptEngine() {
 void LuaScriptEngine::executeScriptWithAppendedModulePaths(std::string& script) {
   for (const auto& module_path : module_paths_) {
     if (std::filesystem::is_regular_file(std::filesystem::status(module_path))) {
-      script = utils::StringUtils::join_pack("package.path = package.path .. [[;", module_path.string(), "]]\n", script);
+      script = utils::string::join_pack("package.path = package.path .. [[;", module_path.string(), "]]\n", script);
     } else {
-      script = utils::StringUtils::join_pack("package.path = package.path .. [[;", module_path.string(), "/?.lua]]\n", script);
+      script = utils::string::join_pack("package.path = package.path .. [[;", module_path.string(), "/?.lua]]\n", script);
     }
   }
   lua_.script(script, sol::script_throw_on_error);
@@ -109,7 +110,8 @@ void LuaScriptEngine::evalFile(const std::filesystem::path& file_name) {
 }
 
 void LuaScriptEngine::initialize(const core::Relationship& success, const core::Relationship& failure, const std::shared_ptr<core::logging::Logger>& logger) {
-  bind("log", logger);
+  lua_logger_ = std::make_unique<LuaLogger>(gsl::make_not_null(logger.get()));
+  bind("log", lua_logger_.get());
   bind("REL_SUCCESS", success);
   bind("REL_FAILURE", failure);
 }
@@ -123,6 +125,11 @@ class TriggerSession {
       lua_session_(std::move(lua_session)) {
   }
 
+  TriggerSession(TriggerSession&&) = delete;
+  TriggerSession(const TriggerSession&) = delete;
+  TriggerSession& operator=(TriggerSession&&) = delete;
+  TriggerSession& operator=(const TriggerSession&) = delete;
+
   ~TriggerSession() {
     script_context_->releaseProcessContext();
     lua_session_->releaseCoreResources();
