@@ -30,15 +30,16 @@ namespace org::apache::nifi::minifi::extensions::lua {
 
 class LuaScriptExecutor : public script::ScriptExecutor {
  public:
-  explicit LuaScriptExecutor(std::string name, const utils::Identifier& uuid = {});
+  explicit LuaScriptExecutor(std::string_view name, const utils::Identifier& uuid = {});
 
-  void onTrigger(const std::shared_ptr<core::ProcessContext> &context, const std::shared_ptr<core::ProcessSession> &session) override;
+  void onTrigger(const std::shared_ptr<core::ProcessContext>& context, const std::shared_ptr<core::ProcessSession>& session) override;
   void initialize(std::filesystem::path script_file,
       std::string script_body,
       std::optional<std::string> module_directory,
       size_t max_concurrent_engines,
       const core::Relationship& success,
       const core::Relationship& failure,
+      const core::Relationship& original,
       const std::shared_ptr<core::logging::Logger>& logger) override;
 
 
